<?php
/**
 * MiNNaK Theme Customizer
 *
 * @package MiNNaK
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function minnak_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'minnak_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'minnak_customize_partial_blogdescription',
			)
		);
	}
}
add_action( 'customize_register', 'minnak_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function minnak_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function minnak_customize_partial_blogdescription() {
	bloginfo( 'description' );
}


function minnak_general_theme_options( $wp_customize ) {

	$wp_customize->add_section(
		'minnak_general_theme_settings',
		array(
			'title'       => __( 'General theme settings', 'minnak' ),
			'priority'    => 134,
			'capability'  => 'edit_theme_options',
		)
	);

	$wp_customize->add_setting(
		'theme_mode',
		array(
			'default'     => 'light',
			'type'        => 'theme_mod',
			'capability'  => 'edit_theme_options',
			'transport'   => 'refresh',
			'sanitize_callback' => 'minnak_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'theme_mode',
		array(
			'description' => __( 'Choose the theme mode', 'minnak' ),
			'settings'    => 'theme_mode',
			'section'     => 'minnak_general_theme_settings',
			'type'        => 'select',
			'priority'    => 9,
			'choices'     => array(
				'light'     => __( 'Light', 'minnak' ),
				'dark'      => __( 'Dark', 'minnak' ),
			),
		)
	);

	$wp_customize->add_setting(
		'column_settings',
		array(
			'default'     => 'three',
			'type'        => 'theme_mod',
			'capability'  => 'edit_theme_options',
			'transport'   => 'refresh',
			'sanitize_callback' => 'minnak_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'column_settings',
		array(
			'description' => __( 'How many columns should the articles be listed?', 'minnak' ),
			'settings'    => 'column_settings',
			'section'     => 'minnak_general_theme_settings',
			'type'        => 'select',
			'priority'    => 10,
			'choices'     => array(
				'one'       => '1',
				'two'       => '2',
				'three'     => '3',
			),
		)
	);

	$wp_customize->add_setting(
		'menu_type',
		array(
			'default'     => 'main',
			'type'        => 'theme_mod',
			'capability'  => 'edit_theme_options',
			'transport'   => 'refresh',
			'sanitize_callback' => 'minnak_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'menu_type',
		array(
			'description' => __( 'Which menu would you like to use?', 'minnak' ),
			'settings'    => 'menu_type',
			'section'     => 'minnak_general_theme_settings',
			'type'        => 'select',
			'priority'    => 11,
			'choices'     => array(
				'main'      => __( 'Only Main Menu', 'minnak' ),
				'category'  => __( 'Only Category Menu', 'minnak' ),
				'both'      => __( 'Both Menus', 'minnak' ),
			),
		)
	);

	$wp_customize->add_setting(
		'show_search',
		array(
			'default'     => true,
			'type'        => 'theme_mod',
			'capability'  => 'edit_theme_options',
			'transport'   => 'refresh',
			'sanitize_callback' => 'minnak_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'show_search',
		array(
			'label'       => __( 'Show search', 'minnak' ),
			'section'     => 'minnak_general_theme_settings',
			'type'        => 'checkbox',
			'settings'    => 'show_search',
			'priority'    => 12,
		)
	);

	$wp_customize->add_setting(
		'show_author_bio',
		array(
			'default'     => false,
			'type'        => 'theme_mod',
			'capability'  => 'edit_theme_options',
			'transport'   => 'refresh',
			'sanitize_callback' => 'minnak_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'show_author_bio',
		array(
			'label'       => __( 'Show author bio on single post', 'minnak' ),
			'section'     => 'minnak_general_theme_settings',
			'type'        => 'checkbox',
			'settings'    => 'show_author_bio',
			'priority'    => 13,
		)
	);

	$wp_customize->add_setting(
		'minnak_footer_credit_checkbox',
		array(
			'default'     => true,
			'capability'  => 'edit_theme_options',
			'transport'   => 'postMessage',
			'sanitize_callback' => 'minnak_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'minnak_footer_credit_checkbox',
		array(
			'label'       => __( 'Show footer credit', 'minnak' ),
			'section'     => 'minnak_general_theme_settings',
			'type'        => 'checkbox',
			'settings'    => 'minnak_footer_credit_checkbox',
			'priority'    => 14,
		)
	);
	$wp_customize->selective_refresh->add_partial(
		'minnak_footer_credit_checkbox',
		array(
			'selector'    => '#site-info #footer-credit-area',
			'capability'  => 'edit_theme_options',
			'settings'    => array( 'minnak_footer_credit_checkbox' ),
			'render_callback' => 'minnak_credit',
		)
	);

	$wp_customize->add_setting(
		'minnak_custom_copyright_textarea',
		array(
			'default'     => '',
			'capability'  => 'edit_theme_options',
			'transport'   => 'postMessage',
			'sanitize_callback' => 'wp_kses_post',
		)
	);
	$wp_customize->add_control(
		'minnak_custom_copyright_textarea',
		array(
			'label'       => esc_html__( 'Footer copyright', 'minnak' ),
			'description' => __( 'Replace the footer copyright text.<br><strong>HTML</strong> is allowed!', 'minnak' ),
			'section'     => 'minnak_general_theme_settings',
			'type'        => 'textarea',
			'input_attrs' => array(
				'style'       => 'border: 1px solid #999',
				'placeholder' => __( 'Enter custom copyright...', 'minnak' ),
			),
			'priority'    => 15,
		)
	);
	$wp_customize->selective_refresh->add_partial(
		'minnak_custom_copyright_textarea',
		array(
			'selector'    => '#site-info #copyright-text-area',
			'section'     => 'minnak_general_theme_settings',
			'settings'    => array(
				'minnak_custom_copyright_textarea',
			),
			'render_callback' => 'minnak_site_copyright',
		)
	);

}

add_action( 'customize_register', 'minnak_general_theme_options' );

//checkbox sanitization function
if ( ! function_exists( 'minnak_sanitize_checkbox' ) ) {
	/**
			* Switch sanitization
			*
			* @param string $input Switch value.
			* @return integer  Sanitized value
			*/
	function minnak_sanitize_checkbox( $input ) {
		if ( false === $input ) {
				return 0;
		} else {
				return 1;
		}
	}
}

//select sanitization function
function minnak_sanitize_select( $input, $setting ) {
	//input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
	$input = sanitize_key( $input );
	//get the list of possible select options
	$choices = $setting->manager->get_control( $setting->id )->choices;
	//return input if valid or return default option
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

function minnak_social_links_array() {
	$social_sites = array( 'Twitter', 'Facebook', 'Instagram', 'Reddit', 'Digg', 'AIM', 'Pinterest', 'Dribbble', 'Behance', 'Tumblr', 'Flickr', 'Linkedin', 'Youtube', 'Vimeo', 'Twitch', 'Discord', 'Whatsapp', 'Telegram', 'Signal', 'Snapchat', 'Viber', 'Codepen', 'Patreon', 'Spotify', 'Anchor-Podcast', 'Google-Podcast', 'Apple-Podcast', 'RSS', 'E-mail' );
	return $social_sites;
}

add_action( 'customize_register', 'minnak_social_links_customizer' );
function minnak_social_links_customizer( $wp_customize ) {
	$wp_customize->add_section(
		'minnak_social_links',
		array(
			'title'       => __( 'Social media links', 'minnak' ),
			'priority'    => 135,
			'description' => __( 'Enter the full URL for each service to appear in the sidebar.', 'minnak' ),
		)
	);
	$social_sites = minnak_social_links_array();
	$priority = 5;
	foreach ( $social_sites as $social_site ) {
		$wp_customize->add_setting(
			"$social_site",
			array(
				'type'              => 'theme_mod',
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control(
			$social_site,
			array(
				'label'    => $social_site . ' ' . __( 'URL:', 'minnak' ),
				'section'  => 'minnak_social_links',
				'type'     => 'text',
				'priority' => $priority,
			)
		);
		$priority = $priority + 1;
	}
}

function minnak_social_links_icons_function() {
	$social_sites = minnak_social_links_array();
	foreach ( $social_sites as $social_site ) {
		if ( strlen( get_theme_mod( $social_site ) ) > 0 ) {
			$active_sites[] = $social_site;
		}
	}
	if ( ! empty( $active_sites ) ) {
		echo "<div id='social' class='left-sidebar-social-links d-flex justify-content-center flex-wrap'>";
		foreach ( $active_sites as $active_site ) {
			$class = $active_site . '-links';
			if ( 'Twitter' === $active_site ) { ?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Twitter', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24V24ZM5.94344 10.4663C5.92844 10.4663 5.91994 10.4663 5.91644 10.4738C5.94551 10.9324 6.06443 11.3808 6.26644 11.7936C6.5773 12.3365 7.04297 12.7744 7.60398 13.0514L8.08199 13.2779L7.51647 13.2879C7.16646 13.2879 7.03996 13.2924 7.00046 13.3444C6.97596 13.3769 6.98796 13.4289 7.00946 13.5044C7.1806 13.888 7.43194 14.2306 7.74657 14.5091C8.0612 14.7875 8.43182 14.9954 8.8335 15.1187L9.43852 15.3256L8.91201 15.6406C8.11451 16.098 7.21555 16.3493 6.29645 16.372C6.0274 16.3612 5.75816 16.3878 5.49643 16.451C6.08006 16.8269 6.71382 17.1185 7.37897 17.3174C8.13221 17.5458 8.9154 17.6602 9.70252 17.6568C11.1314 17.6651 12.5371 17.2966 13.7781 16.5885C15.2203 15.6699 16.3528 14.3387 17.0282 12.768C17.3951 11.8217 17.6188 10.8261 17.6917 9.81385C17.6917 9.35791 17.7242 9.29892 18.2672 8.75999C18.5135 8.52578 18.7407 8.27235 18.9467 8.00209C18.9827 7.9336 19.0037 7.8901 18.9922 7.87111C18.9877 7.86311 18.9772 7.85961 18.9607 7.85961C18.8157 7.88645 18.6736 7.92765 18.5367 7.98259C18.3181 8.07525 18.0883 8.13911 17.8532 8.17257C17.8097 8.17257 17.7842 8.16257 17.7752 8.14207C17.7542 8.09208 17.8252 7.98709 18.0007 7.79562C18.2965 7.49721 18.523 7.13743 18.6642 6.74176C18.6642 6.73626 18.6587 6.73326 18.6482 6.73326C18.5438 6.75572 18.4438 6.79524 18.3522 6.85024C18.0759 6.98575 17.7888 7.0978 17.4937 7.1852L16.9672 7.35267L16.4887 7.02772C16.2306 6.85069 15.9523 6.70517 15.6597 6.59427C15.4052 6.53015 15.1435 6.49923 14.8811 6.50229C14.5669 6.49676 14.2538 6.54132 13.9536 6.63427C13.3698 6.83326 12.8676 7.21861 12.5242 7.73098C12.1809 8.24335 12.0155 8.85434 12.0536 9.4699L12.0831 9.95233L11.5951 9.89334C9.83599 9.67065 8.20177 8.86669 6.95196 7.60914L6.30795 6.96923L6.14194 7.44166C5.9643 7.93604 5.92679 8.46989 6.03356 8.98424C6.14033 9.49859 6.38722 9.97342 6.74696 10.3563C6.92346 10.5433 6.99696 10.6522 6.97546 10.6997C6.96696 10.7192 6.94346 10.7287 6.90346 10.7287C6.72187 10.7047 6.5445 10.6556 6.37645 10.5827C6.23684 10.5281 6.09163 10.489 5.94344 10.4663V10.4663Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Facebook' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Facebook', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9956 24C9.22708 23.9979 6.54439 23.0391 4.40188 21.2862C2.25936 19.5332 0.78872 17.0938 0.239027 14.3811C-0.310665 11.6683 0.0943811 8.84899 1.38557 6.40059C2.67675 3.95219 4.7747 2.02521 7.32411 0.94602C10.2569 -0.292643 13.5618 -0.315796 16.5117 0.881653C19.4615 2.0791 21.8148 4.39907 23.0538 7.33118C24.2927 10.2633 24.3159 13.5674 23.1181 16.5165C21.9204 19.4657 19.5999 21.8184 16.6671 23.0571C15.1892 23.6824 13.6004 24.0031 11.9956 24V24ZM8.49523 9.71386V12.192H9.98239V19.3821H12.9582V12.1915H14.9459L15.2089 9.71386H12.9587L12.9622 8.47353C12.9622 7.83961 13.0082 7.48116 13.9518 7.48116H15.1929V5.00248H13.2067C12.0476 5.00248 11.2275 5.28195 10.7 5.85637C10.169 6.527 9.91255 7.37414 9.98239 8.22656V9.71386H8.49523Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Instagram' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Instagram', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24V24ZM11.9966 5.00248C10.1165 5.00248 9.86703 5.01048 9.11101 5.04498C8.53005 5.05706 7.9553 5.16709 7.41097 5.37044C6.94546 5.54989 6.52261 5.82467 6.16957 6.17714C5.81652 6.52961 5.54108 6.95199 5.36092 7.41717C5.15729 7.96134 5.04723 8.53605 5.03542 9.11694C5.00442 9.86384 4.99641 10.1123 4.99641 12.0016C4.99641 13.8908 5.00441 14.1418 5.03842 14.8867C5.05081 15.4675 5.16068 16.0421 5.36342 16.5865C5.54315 17.0518 5.81805 17.4744 6.17055 17.8274C6.52304 18.1803 6.94536 18.4558 7.41047 18.6362C7.95497 18.8389 8.52964 18.9487 9.11051 18.9611C9.86603 18.9926 10.116 19.0006 11.9966 19.0006C13.8771 19.0006 14.1266 18.9926 14.8821 18.9581C15.463 18.9457 16.0377 18.8359 16.5822 18.6332C17.0472 18.4526 17.4694 18.1771 17.8219 17.8241C18.1743 17.4712 18.4493 17.0486 18.6292 16.5835C18.8317 16.039 18.9418 15.4645 18.9547 14.8837C18.9882 14.1208 18.9967 13.8693 18.9967 12.0016C18.9967 10.1338 18.9887 9.88084 18.9542 9.11544C18.9414 8.53466 18.8313 7.96013 18.6287 7.41567C18.449 6.95056 18.1741 6.52817 17.8214 6.1756C17.4688 5.82304 17.0464 5.5481 16.5812 5.36844C16.0368 5.1654 15.4621 5.05537 14.8811 5.04298C14.1246 5.01048 13.8746 5.00248 11.9966 5.00248ZM11.9966 17.7358C10.1215 17.7358 9.90103 17.7288 9.16801 17.6948C8.72407 17.6895 8.28434 17.608 7.86798 17.4538C7.56602 17.3374 7.29174 17.1592 7.06277 16.9305C6.8338 16.7018 6.65521 16.4278 6.53845 16.126C6.38444 15.7097 6.30293 15.27 6.29745 14.8262C6.26444 14.1073 6.25744 13.8893 6.25744 11.9976C6.25744 10.1058 6.26444 9.88834 6.29745 9.17043C6.30313 8.72659 6.38463 8.28699 6.53845 7.87061C6.65536 7.56879 6.834 7.29471 7.06294 7.06589C7.29188 6.83707 7.56608 6.65856 7.86798 6.54178C8.28439 6.38786 8.72409 6.30636 9.16801 6.30081C9.82403 6.27132 10.0705 6.26282 11.3681 6.26132H11.9961C13.8656 6.26132 14.0866 6.26832 14.8246 6.30181C15.2686 6.30705 15.7083 6.38838 16.1247 6.54228C16.4266 6.65896 16.7008 6.83743 16.9296 7.06627C17.1585 7.29511 17.337 7.56925 17.4537 7.87111C17.6073 8.28752 17.6887 8.72712 17.6942 9.17093C17.7277 9.90584 17.7347 10.1268 17.7347 11.9991C17.7347 13.8713 17.7277 14.0913 17.6942 14.8262C17.6887 15.27 17.6074 15.7096 17.4537 16.126C17.3408 16.4297 17.1618 16.7044 16.9297 16.9304C16.7042 17.1629 16.4292 17.3417 16.1252 17.4533C15.7091 17.6084 15.2692 17.6899 14.8251 17.6943C14.0921 17.7288 13.8716 17.7358 11.9966 17.7358ZM11.9966 8.40704C11.2857 8.40713 10.5908 8.61799 9.99972 9.01295C9.40867 9.4079 8.94802 9.96922 8.67602 10.6259C8.40402 11.2826 8.33287 12.0052 8.47159 12.7023C8.6103 13.3995 8.95264 14.0398 9.45532 14.5424C9.958 15.045 10.5985 15.3873 11.2957 15.526C11.9929 15.6647 12.7156 15.5936 13.3724 15.3216C14.0292 15.0496 14.5906 14.5891 14.9857 13.9981C15.3807 13.4071 15.5916 12.7123 15.5917 12.0016C15.5903 11.0486 15.2111 10.1351 14.5372 9.46131C13.8633 8.78749 12.9496 8.40836 11.9966 8.40704V8.40704ZM15.7332 7.42567C15.567 7.42567 15.4046 7.47494 15.2664 7.56725C15.1283 7.65956 15.0206 7.79076 14.957 7.94426C14.8935 8.09776 14.8769 8.26666 14.9093 8.42959C14.9418 8.59253 15.0218 8.74218 15.1394 8.85962C15.2569 8.97706 15.4066 9.05702 15.5696 9.08937C15.7326 9.12172 15.9015 9.10501 16.055 9.04137C16.2085 8.97772 16.3396 8.86999 16.4319 8.73181C16.5241 8.59362 16.5733 8.43119 16.5732 8.26505C16.5728 8.04256 16.4842 7.82928 16.3269 7.67195C16.1695 7.51462 15.9562 7.42606 15.7337 7.42567H15.7332ZM11.9966 14.3348C11.535 14.3348 11.0839 14.1979 10.7001 13.9415C10.3164 13.6852 10.0173 13.3208 9.84065 12.8944C9.66403 12.4681 9.61782 11.999 9.70786 11.5464C9.7979 11.0938 10.0202 10.678 10.3465 10.3517C10.6729 10.0254 11.0887 9.80323 11.5413 9.7132C11.994 9.62317 12.4632 9.66938 12.8896 9.84597C13.316 10.0226 13.6804 10.3216 13.9369 10.7053C14.1933 11.089 14.3301 11.5401 14.3301 12.0016C14.3295 12.6202 14.0834 13.2132 13.6459 13.6506C13.2084 14.0881 12.6153 14.3341 11.9966 14.3348Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Reddit' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Reddit', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M12 24C10.3954 24.0031 8.80668 23.6824 7.32899 23.057C5.90306 22.4547 4.60765 21.5814 3.51454 20.4855C2.41845 19.3924 1.54494 18.097 0.942528 16.671C0.317324 15.1933 -0.00324498 13.6045 2.47629e-05 12C-0.00312797 10.3954 0.317601 8.80668 0.943016 7.32899C1.54542 5.90303 2.41893 4.60762 3.51503 3.51454C4.60811 2.41845 5.90352 1.54494 7.32948 0.942527C8.80705 0.31735 10.3956 -0.00321924 12 2.43706e-05C13.6046 -0.00305976 15.1933 0.317667 16.671 0.943016C18.097 1.54545 19.3924 2.41895 20.4855 3.51503C21.5815 4.60816 22.455 5.90356 23.0575 7.32948C23.6826 8.80705 24.0032 10.3956 24 12C24.0031 13.6046 23.6824 15.1933 23.057 16.671C22.4545 18.0969 21.581 19.3923 20.485 20.4855C19.3918 21.5814 18.0964 22.4547 16.6705 23.057C15.193 23.6823 13.6044 24.003 12 24V24ZM5.50001 9.85352C4.97114 9.85352 4.46382 10.063 4.08901 10.4362C3.71419 10.8093 3.5024 11.3156 3.50002 11.8445C3.50014 12.1768 3.58376 12.5037 3.7433 12.7952C3.90285 13.0866 4.13315 13.3333 4.41298 13.5124C4.38492 13.6916 4.37057 13.8726 4.37001 14.054C4.37001 16.8844 7.82006 19.187 12.0656 19.187C16.311 19.187 19.7605 16.8844 19.7605 14.054C19.7604 13.8858 19.748 13.7179 19.7235 13.5515C20.0195 13.3753 20.265 13.1256 20.4361 12.8267C20.6073 12.5277 20.6983 12.1895 20.7004 11.845C20.698 11.3161 20.4864 10.8098 20.1116 10.4366C19.7367 10.0635 19.2293 9.854 18.7004 9.85401C18.2158 9.85447 17.7479 10.0309 17.3835 10.3505C15.9492 9.48238 14.3165 8.99583 12.641 8.93702L13.6055 5.90199L16.2364 6.51905C16.2503 6.94661 16.4309 7.35169 16.7395 7.64796C17.0476 7.947 17.4602 8.11423 17.8895 8.11402C18.3279 8.11442 18.7486 7.94092 19.0592 7.6316C19.3698 7.32228 19.545 6.90237 19.5465 6.464C19.545 6.02563 19.3698 5.60572 19.0592 5.2964C18.7486 4.98708 18.3279 4.81358 17.8895 4.81398C17.575 4.81505 17.2672 4.90525 17.0017 5.07399C16.7362 5.24273 16.524 5.48311 16.3895 5.76747L13.4325 5.07497C13.4035 5.06823 13.3738 5.06487 13.344 5.06496C13.2623 5.06455 13.1825 5.09045 13.1166 5.13869C13.0506 5.18692 13.0019 5.25502 12.9775 5.33302L11.8361 8.92554C10.0579 8.93296 8.31416 9.41627 6.78602 10.3254C6.4262 10.0217 5.97088 9.85452 5.50001 9.85303V9.85352ZM12.0656 18.4205C8.24706 18.4205 5.14052 16.4619 5.14052 14.0544C5.14052 13.9784 5.14448 13.8959 5.15248 13.8044C5.1769 13.5479 5.23532 13.2957 5.32606 13.0544C5.59694 12.3812 6.04635 11.7947 6.62599 11.358C6.82894 11.196 7.04227 11.0473 7.26454 10.913C8.72573 10.0817 10.3836 9.65892 12.0645 9.68897C13.7673 9.65615 15.4466 10.091 16.9195 10.946C17.1418 11.0834 17.3545 11.2353 17.5565 11.401C18.1143 11.8337 18.5459 12.4079 18.8065 13.064C18.8971 13.3051 18.9547 13.5574 18.978 13.814C18.9855 13.9055 18.989 13.9825 18.989 14.056C18.99 16.4615 15.8834 18.42 12.0649 18.42L12.0656 18.4205ZM12.1 17.378H12.1045H12.109C13.3985 17.378 14.3091 17.094 14.8986 16.51C14.9343 16.4744 14.9626 16.4321 14.9819 16.3855C15.0012 16.3389 15.0111 16.289 15.011 16.2385C15.011 16.1883 15.0011 16.1386 14.9818 16.0923C14.9625 16.0459 14.9342 16.0038 14.8986 15.9685C14.8628 15.9327 14.8202 15.9043 14.7734 15.885C14.7267 15.8657 14.6766 15.8558 14.626 15.856C14.5754 15.8558 14.5254 15.8655 14.4786 15.8848C14.4319 15.904 14.3893 15.9323 14.3535 15.968C13.917 16.401 13.183 16.6114 12.109 16.6114H12.097H12.0935H12.0905C11.016 16.6114 10.2821 16.401 9.84656 15.968C9.81079 15.9322 9.7682 15.9038 9.72144 15.8845C9.67468 15.8652 9.62457 15.8553 9.57398 15.8555C9.52345 15.8553 9.47345 15.8652 9.42676 15.8845C9.38007 15.9038 9.33765 15.9322 9.30201 15.968C9.26612 16.0035 9.23767 16.0458 9.21827 16.0924C9.19887 16.139 9.18888 16.189 9.18897 16.2395C9.18902 16.2897 9.19912 16.3395 9.21851 16.3859C9.23791 16.4322 9.26626 16.4742 9.30201 16.5095C9.88901 17.094 10.802 17.378 12.0905 17.378H12.0955H12.1ZM9.53248 11.942C9.21775 11.9455 8.91688 12.0717 8.69385 12.2938C8.47083 12.5159 8.34331 12.8163 8.33851 13.131C8.34207 13.4444 8.46979 13.7436 8.69361 13.963C8.91743 14.1824 9.21906 14.3042 9.53248 14.3015C9.84346 14.3016 10.1419 14.1785 10.3623 13.9591C10.5827 13.7397 10.7072 13.442 10.7085 13.131C10.7098 12.8175 10.5868 12.5162 10.3663 12.2933C10.1459 12.0704 9.84597 11.9441 9.53248 11.942V11.942ZM14.6855 11.942C14.3706 11.9452 14.0693 12.0712 13.8459 12.2932C13.6226 12.5152 13.4947 12.8156 13.4895 13.1305C13.4932 13.4443 13.6211 13.7437 13.8453 13.9633C14.0695 14.1828 14.3718 14.3044 14.6855 14.3015C14.9967 14.3018 15.2952 14.1786 15.5156 13.9591C15.7361 13.7396 15.8604 13.4416 15.8614 13.1305C15.8626 12.817 15.7396 12.5158 15.5192 12.293C15.2987 12.0701 14.999 11.9438 14.6855 11.9415V11.942ZM19.5119 12.7605C19.1951 11.9965 18.6857 11.3275 18.0334 10.819C18.2319 10.6892 18.4639 10.6198 18.701 10.619C19.0262 10.6188 19.3382 10.7475 19.5686 10.9769C19.799 11.2064 19.929 11.5179 19.93 11.843C19.9295 12.0165 19.8919 12.1878 19.8199 12.3457C19.7479 12.5036 19.6431 12.6443 19.5124 12.7585L19.5119 12.7605ZM4.63698 12.715C4.52084 12.6018 4.42857 12.4666 4.36562 12.3171C4.30267 12.1677 4.27036 12.0071 4.27052 11.845C4.27145 11.5198 4.40143 11.2082 4.63185 10.9788C4.86228 10.7493 5.17432 10.6206 5.49953 10.621C5.72028 10.6212 5.93683 10.681 6.12648 10.7939C5.47471 11.297 4.96231 11.9582 4.63795 12.715H4.63698ZM17.892 7.34706C17.6573 7.34732 17.4321 7.25452 17.2657 7.089C17.0994 6.92348 17.0054 6.69868 17.0045 6.464C17.0053 6.22923 17.0991 6.00439 17.2655 5.83876C17.4319 5.67313 17.6572 5.58019 17.892 5.58046C18.1267 5.58019 18.352 5.67313 18.5184 5.83876C18.6848 6.00439 18.7787 6.22923 18.7795 6.464C18.7786 6.69877 18.6845 6.92358 18.5181 7.08912C18.3516 7.25466 18.1262 7.34745 17.8915 7.34706H17.892Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Digg' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Digg', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M12.0175 24C9.24409 23.9984 6.55647 23.0393 4.40997 21.2851C2.26347 19.5309 0.790083 17.0895 0.239415 14.3744C-0.311253 11.6594 0.0946601 8.83772 1.38839 6.38739C2.68212 3.93706 4.78411 2.00877 7.33826 0.929196C10.2733 -0.296284 13.575 -0.310096 16.5202 0.890785C19.4654 2.09167 21.8142 4.40937 23.0522 7.33635C24.2901 10.2633 24.3164 13.561 23.1252 16.5073C21.934 19.4536 19.6225 21.8084 16.6968 23.0559C15.2165 23.6819 13.625 24.003 12.0175 24V24ZM15.7742 15.0862V16.2453H19.5308V9.57486H15.7742V14.5053H18.0862V15.0852L15.7742 15.0862ZM11.182 15.0862V16.2453H14.9387V9.57486H11.182V14.5053H13.4951V15.0852L11.182 15.0862ZM9.09586 9.57486V14.5778H10.7653V9.57486H9.09586ZM4.50425 9.55635V14.5778H8.26089V7.49012H6.81584V9.55635H4.50425ZM9.09586 7.49012V9.15811H10.7653V7.49012H9.09586ZM6.81533 13.3971H5.9488V10.7386H6.81533V13.3966V13.3971ZM18.0852 13.3471H17.2192V10.7351H18.0867V13.3436L18.0852 13.3471ZM13.4936 13.3471H12.6281V10.7351H13.4956V13.3436L13.4936 13.3471Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'AIM' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'AIM', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24V24ZM11.1791 15.3716C11.9164 15.5501 12.6001 15.9032 13.1726 16.401C13.8104 16.982 14.3337 17.6772 14.7156 18.4507C15.5592 17.7508 15.7382 17.6078 16.3317 17.1334L16.5787 16.9359C16.2256 16.1542 15.7115 15.4558 15.0701 14.8862C14.4321 14.2987 13.7108 13.8087 12.9296 13.4319C12.9381 13.2049 12.9461 13.0849 12.9541 12.9584C12.9586 12.8859 12.9636 12.8085 12.9691 12.7085C13.2495 12.7812 13.538 12.818 13.8276 12.818C14.9956 12.7473 16.103 12.2744 16.9617 11.4796C16.9587 11.4741 16.4912 10.6107 15.9117 9.73286C15.4384 10.1757 14.8148 10.4224 14.1666 10.4233C13.9579 10.4224 13.7499 10.3991 13.5461 10.3538C13.3078 10.3271 13.0882 10.212 12.9306 10.0313C12.9075 9.99664 12.8917 9.9576 12.8842 9.91659C12.8767 9.87557 12.8777 9.83347 12.8871 9.79285C12.6383 9.69227 12.3956 9.57742 12.1601 9.4489C11.7022 9.20023 11.228 8.98309 10.7405 8.79898C9.55002 9.51939 8.8815 11.3257 8.95351 13.6293C8.64015 14.3157 8.18638 14.9288 7.62148 15.4291C7.02182 15.8674 6.32862 16.1605 5.59643 16.2855C5.94644 17.1009 6.08494 17.3988 6.57945 18.4312C8.40802 17.9458 10.0251 16.8702 11.1796 15.3716H11.1791ZM13.2276 4.40256C12.6924 4.40168 12.1783 4.61144 11.7966 4.98649C11.6066 5.16881 11.4555 5.38764 11.3523 5.62982C11.2491 5.872 11.1959 6.13254 11.1959 6.3958C11.1959 6.65906 11.2491 6.9196 11.3523 7.16178C11.4555 7.40396 11.6066 7.62279 11.7966 7.80512C12.1781 8.17992 12.6917 8.38966 13.2266 8.38904C13.7633 8.38917 14.2788 8.17963 14.6631 7.80512C14.8551 7.62394 15.0079 7.40549 15.1124 7.16316C15.2169 6.92082 15.2708 6.6597 15.2708 6.3958C15.2708 6.1319 15.2169 5.87078 15.1124 5.62845C15.0079 5.38611 14.8551 5.16766 14.6631 4.98649C14.279 4.61222 13.7639 4.4027 13.2276 4.40256V4.40256Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Pinterest' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Pinterest', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M10.682 17.4623V17.4668L9.93567 20.3163C9.57472 21.4236 9.07325 22.4801 8.44353 23.4598C11.0049 24.2556 13.7589 24.1701 16.266 23.217C18.773 22.2638 20.8884 20.498 22.2743 18.2016C23.6601 15.9051 24.2366 13.2104 23.9116 10.5479C23.5865 7.8854 22.3787 5.40859 20.4811 3.51304C18.7915 1.82665 16.6381 0.681466 14.2954 0.223403C11.9526 -0.23466 9.52658 0.0151358 7.32631 0.940963C5.12879 1.8703 3.25817 3.43367 1.95339 5.43136C0.648608 7.42905 -0.0310992 9.77038 0.0010928 12.1563C0.0332848 14.5422 0.775914 16.8643 2.13412 18.8261C3.49233 20.7878 5.40445 22.3001 7.62624 23.1698C7.46632 22.0266 7.48065 20.8658 7.66872 19.7269C7.88417 18.797 9.06338 13.8139 9.07488 13.7634C8.83312 13.2009 8.71106 12.5943 8.71647 11.9822C8.69718 11.2373 8.9182 10.506 9.34682 9.8965C9.52057 9.64675 9.75052 9.44128 10.0182 9.2966C10.2846 9.15235 10.5815 9.07353 10.8844 9.06664C11.0998 9.0571 11.3144 9.09713 11.5118 9.18362C11.7102 9.27058 11.8863 9.40153 12.0267 9.56655C12.2858 9.90809 12.4185 10.3289 12.4021 10.7574C12.3274 11.5893 12.1424 12.4077 11.8522 13.191C11.6937 13.7049 11.5288 14.2368 11.4068 14.7522C11.3406 15.0047 11.3329 15.269 11.3842 15.525C11.4355 15.781 11.5444 16.0219 11.7027 16.2295C11.8809 16.4506 12.1073 16.6281 12.3646 16.7484C12.6206 16.8681 12.9008 16.9269 13.1834 16.9204C13.7219 16.9082 14.249 16.7621 14.717 16.4954C15.1867 16.2273 15.5835 15.8482 15.8727 15.3911C16.6242 14.2084 17.0027 12.8269 16.959 11.4263C16.959 8.55222 14.8985 6.54255 11.9477 6.54255C11.2092 6.52032 10.4741 6.65192 9.78921 6.92899C9.10148 7.20732 8.47851 7.62444 7.95915 8.15429C7.04263 9.12733 6.53185 10.4134 6.531 11.7502C6.53301 12.734 6.84506 13.692 7.42278 14.4883C7.46521 14.5335 7.49518 14.5889 7.50976 14.6492C7.52452 14.7096 7.52348 14.7728 7.50676 14.8327C7.45128 15.0607 7.3568 15.4441 7.28132 15.7515C7.23133 15.956 7.18884 16.126 7.17085 16.192C7.13585 16.3389 7.07087 16.4074 6.9649 16.4074C6.89636 16.4028 6.82958 16.3837 6.76894 16.3514C5.97785 15.9255 5.35182 15.2474 4.99038 14.4248C4.57328 13.5771 4.34945 12.6474 4.33504 11.7027C4.32385 10.7669 4.49693 9.83809 4.84441 8.96915C5.19029 8.10382 5.70443 7.31573 6.35704 6.65053C7.14576 5.90521 8.07539 5.32495 9.09138 4.94381C10.1037 4.56433 11.182 4.39261 12.2621 4.43889C14.2024 4.40832 16.0819 5.11552 17.5208 6.41757C18.2022 7.04801 18.7437 7.8144 19.1104 8.6672C19.4795 9.52305 19.6667 10.4462 19.6603 11.3783C19.6983 13.2883 19.0783 15.1533 17.9042 16.6604C17.3691 17.3378 16.6887 17.8864 15.9132 18.2656C15.1414 18.6425 14.2942 18.8393 13.4353 18.841C12.2771 18.841 11.0964 18.2486 10.682 17.4623Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Dribbble' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Dribbble', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24V24ZM11.9966 5.00248C11.523 5.00262 11.0506 5.05019 10.5865 5.14447C10.1356 5.23623 9.69489 5.37272 9.27101 5.55191C8.85441 5.7285 8.45588 5.94498 8.08099 6.19833C7.33593 6.70106 6.69445 7.34227 6.19144 8.08708C5.40978 9.2427 4.99344 10.6065 4.99641 12.0016C4.99583 12.9208 5.1766 13.8311 5.52838 14.6804C5.88016 15.5297 6.39603 16.3012 7.04646 16.9509C7.68443 17.5897 8.44001 18.099 9.27151 18.4507C10.1342 18.8135 11.0607 19.0003 11.9966 19.0003C12.9325 19.0003 13.8589 18.8135 14.7216 18.4507C15.9716 17.9209 17.0411 17.0401 17.8007 15.915C18.0548 15.5411 18.2712 15.1428 18.4467 14.7262C18.811 13.864 18.9986 12.9375 18.9986 12.0016C18.9986 11.0656 18.811 10.1391 18.4467 9.27692C18.2714 8.85997 18.0552 8.46141 17.8012 8.08708C17.5497 7.71592 17.2636 7.36942 16.9467 7.05221C16.6289 6.73621 16.2822 6.45066 15.9112 6.19933C15.5363 5.94578 15.1378 5.72913 14.7211 5.55241C14.2974 5.37329 13.8569 5.2368 13.4061 5.14497C12.9422 5.05061 12.47 5.00288 11.9966 5.00248ZM11.9966 17.9788C10.6645 17.9811 9.37036 17.5353 8.32249 16.7129C8.60203 16.1803 8.95853 15.6918 9.38052 15.2631C10.3912 14.2218 11.6374 13.4386 13.0141 12.9794L13.0341 12.9729H13.0371H13.0436L13.0536 12.9699C13.6214 14.4389 14.0489 15.9583 14.3306 17.5078C13.5925 17.8211 12.7985 17.9814 11.9966 17.9788V17.9788ZM15.3377 16.9584C15.0702 15.5055 14.681 14.0776 14.1741 12.69C14.5856 12.6251 15.0016 12.5928 15.4182 12.5935C16.2579 12.5915 17.0935 12.7116 17.8987 12.9499C17.768 13.7575 17.4734 14.5297 17.033 15.2191C16.5927 15.9086 16.0159 16.5007 15.3382 16.9589L15.3377 16.9584ZM7.54997 15.9955C6.56295 14.8994 6.0173 13.4765 6.01844 12.0016C6.01844 11.9716 6.01844 11.9411 6.01844 11.9116V11.8731C6.01844 11.8646 6.01844 11.8561 6.01844 11.8476V11.8431C6.01844 11.8321 6.01844 11.8216 6.01844 11.8106C6.03394 11.8106 6.10594 11.8131 6.23544 11.8131C8.23882 11.7991 10.2309 11.5118 12.1566 10.9592C12.3381 11.3157 12.5011 11.6591 12.6416 11.9751C12.5646 11.9971 12.4831 12.0211 12.4056 12.0471C10.3826 12.7709 8.66797 14.1645 7.54597 15.9965L7.54997 15.9955ZM17.9727 11.9401H17.9647C17.0497 11.7593 16.1193 11.6675 15.1867 11.6661C14.7264 11.6647 14.2665 11.6921 13.8096 11.7481C13.7801 11.6766 13.7486 11.5981 13.7096 11.5136L13.6991 11.4886L13.6781 11.4386C13.5616 11.1652 13.4316 10.8817 13.2806 10.5717C14.5841 10.099 15.7352 9.28178 16.6112 8.20706C17.4764 9.26103 17.956 10.5786 17.9707 11.9421L17.9727 11.9401ZM6.24944 10.7697H6.14944H6.14644C6.33874 9.86729 6.7365 9.02132 7.30883 8.29752C7.88117 7.57372 8.61267 6.99157 9.44652 6.59627L9.45052 6.60127C10.2531 7.70524 10.9928 8.85357 11.6661 10.0408C9.89723 10.5048 8.07804 10.7496 6.24944 10.7697V10.7697ZM12.8221 9.67887C12.1592 8.47134 11.4157 7.30986 10.5965 6.20233L10.5885 6.19083C11.0497 6.08042 11.5223 6.02471 11.9966 6.02485C13.4512 6.02377 14.856 6.55433 15.9467 7.51665C15.1319 8.51846 14.0494 9.26843 12.8251 9.67937L12.8221 9.67887Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Behance' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Behance', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M12.0175 24C9.24409 23.9984 6.55647 23.0393 4.40997 21.2851C2.26347 19.5309 0.790083 17.0895 0.239415 14.3744C-0.311253 11.6594 0.0946601 8.83772 1.38839 6.38739C2.68212 3.93706 4.78411 2.00877 7.33826 0.929196C10.2733 -0.296284 13.575 -0.310096 16.5202 0.890785C19.4654 2.09167 21.8142 4.40937 23.0522 7.33635C24.2901 10.2633 24.3164 13.561 23.1252 16.5073C21.934 19.4536 19.6225 21.8084 16.6968 23.0559C15.2165 23.6819 13.625 24.003 12.0175 24V24ZM16.6207 9.69143C16.1694 9.67489 15.7194 9.74949 15.2977 9.91076C14.876 10.072 14.4911 10.3167 14.1663 10.63C13.8347 10.9933 13.5799 11.4196 13.4173 11.8836C13.2546 12.3476 13.1874 12.8396 13.2196 13.3301C13.2196 14.5763 13.5703 15.4874 14.268 16.0382C14.9532 16.5875 15.8083 16.8817 16.6868 16.8702C17.1627 16.8973 17.639 16.8234 18.0842 16.6534C18.5295 16.4835 18.9337 16.2213 19.2703 15.8841C19.6175 15.5582 19.8506 15.1293 19.935 14.6609H18.1018C18.0115 14.8398 17.8858 14.9984 17.7321 15.1272C17.4463 15.3428 17.0942 15.4523 16.7364 15.4369C16.3888 15.4466 16.0456 15.3582 15.7461 15.1817C15.5134 15.0258 15.325 14.8125 15.199 14.5626C15.073 14.3126 15.0137 14.0344 15.0268 13.7549H20.0317C20.0472 13.3062 20.0272 12.8571 19.9721 12.4116C19.8994 11.9083 19.7108 11.4288 19.4211 11.0107C19.1292 10.5714 18.7179 10.2243 18.2355 10.0101C17.7254 9.79254 17.1753 9.68398 16.6207 9.69143V9.69143ZM5.00514 7.49012V16.6406H9.19003C9.63033 16.6437 10.0698 16.6024 10.5018 16.5175C10.8813 16.4445 11.2396 16.2874 11.5502 16.0577C11.8138 15.8625 12.037 15.618 12.2074 15.3378C12.4847 14.9022 12.6286 14.3951 12.6216 13.8789C12.6356 13.4063 12.51 12.94 12.2605 12.5381C12.001 12.1583 11.6236 11.8744 11.1866 11.7301C11.4553 11.6061 11.6964 11.4293 11.8953 11.2103C12.1961 10.8273 12.3488 10.3488 12.3256 9.86253C12.338 9.36335 12.1885 8.87354 11.8993 8.4662C11.429 7.83532 10.6196 7.50713 9.49507 7.49062L5.00514 7.49012ZM14.6076 7.91687V9.05555H18.5856V7.91687H14.6076ZM9.11239 15.0521H6.85841V12.6122H9.14495C9.46165 12.6012 9.77731 12.6542 10.0731 12.7678C10.2618 12.8493 10.4202 12.9877 10.5262 13.1636C10.6322 13.3395 10.6804 13.5442 10.6641 13.7489C10.6881 13.9784 10.6428 14.2098 10.5341 14.4134C10.4254 14.617 10.2582 14.7835 10.0541 14.8915C9.75532 15.0119 9.43418 15.0667 9.11239 15.0521ZM18.1669 12.5872H15.0729C15.1165 12.1959 15.2845 11.8289 15.5523 11.54C15.6951 11.4063 15.8637 11.3031 16.0479 11.2367C16.232 11.1703 16.4277 11.1421 16.6232 11.1538C17.0109 11.1423 17.3897 11.2713 17.6895 11.517C17.8377 11.6536 17.9565 11.8188 18.0387 12.0027C18.1208 12.1866 18.1646 12.3853 18.1674 12.5867L18.1669 12.5872ZM9.11239 11.0983H6.85841V9.07907H8.87998C9.2511 9.0697 9.62144 9.11763 9.97792 9.22115C10.1413 9.28994 10.2781 9.40936 10.3683 9.56179C10.4585 9.71421 10.4972 9.89156 10.4788 10.0677C10.4941 10.2227 10.4671 10.379 10.4006 10.52C10.3341 10.6609 10.2306 10.7812 10.1011 10.8681C9.79872 11.0334 9.45682 11.113 9.11239 11.0983V11.0983Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Tumblr' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Tumblr', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24ZM10.8406 5.00248C10.8131 5.00555 10.7877 5.01861 10.7693 5.03917C10.7509 5.05973 10.7406 5.08635 10.7405 5.11397C10.5075 7.07121 9.62352 8.33155 8.03749 8.96796C8.0256 8.97298 8.01546 8.98141 8.00835 8.99217C8.00123 9.00293 7.99745 9.01555 7.99748 9.02845V11.0242C7.99735 11.0327 7.99889 11.0411 8.00201 11.0489C8.00513 11.0568 8.00977 11.064 8.01567 11.0701C8.02156 11.0762 8.0286 11.081 8.03638 11.0844C8.04415 11.0878 8.05252 11.0896 8.06099 11.0897H9.54402C9.56104 11.0899 9.57727 11.0969 9.58916 11.1091C9.60106 11.1213 9.60766 11.1377 9.60752 11.1547V15.5361C9.60752 16.9619 10.426 19.3751 13.4931 19.3751H13.5981C14.464 19.3802 15.3049 19.0852 15.9777 18.5402C15.9864 18.5313 15.9924 18.5201 15.9952 18.5079C15.9979 18.4957 15.9972 18.483 15.9932 18.4712L15.3637 16.548C15.3612 16.5397 15.357 16.5321 15.3514 16.5256C15.3458 16.5191 15.3388 16.5138 15.3311 16.5101C15.3233 16.5065 15.3148 16.5045 15.3062 16.5043C15.2976 16.5041 15.2891 16.5057 15.2812 16.509C14.9312 16.65 14.5584 16.7259 14.1811 16.7329C13.3271 16.7329 12.8871 16.2575 12.8726 15.3201V11.1557C12.8725 11.1472 12.8741 11.1388 12.8773 11.131C12.8805 11.1231 12.8852 11.116 12.8911 11.1099C12.8971 11.1039 12.9042 11.0991 12.912 11.0958C12.9198 11.0925 12.9281 11.0907 12.9366 11.0907H15.4117C15.4201 11.0906 15.4285 11.0888 15.4363 11.0854C15.444 11.082 15.4511 11.0772 15.457 11.0711C15.4629 11.065 15.4675 11.0578 15.4706 11.0499C15.4738 11.0421 15.4753 11.0337 15.4752 11.0252V8.707C15.4753 8.69853 15.4738 8.69011 15.4706 8.68224C15.4675 8.67436 15.4629 8.66718 15.457 8.6611C15.4511 8.65502 15.444 8.65016 15.4363 8.64679C15.4285 8.64343 15.4201 8.64163 15.4117 8.6415H12.9466C12.9296 8.64124 12.9134 8.63426 12.9015 8.62209C12.8896 8.60991 12.883 8.59353 12.8831 8.57651V5.06748C12.8832 5.05046 12.8766 5.03408 12.8647 5.0219C12.8528 5.00973 12.8366 5.00275 12.8196 5.00248H10.8406Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Flickr' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Flickr', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9968 24C9.22812 23.9984 6.54514 23.04 4.40235 21.2871C2.25956 19.5341 0.788718 17.0945 0.239001 14.3814C-0.310715 11.6684 0.0944965 8.84871 1.38599 6.40016C2.67748 3.95161 4.77584 2.02472 7.32557 0.945927C10.2582 -0.292675 13.5628 -0.315765 16.5124 0.881736C19.4621 2.07924 21.8151 4.39924 23.0539 7.33136C24.2927 10.2635 24.3158 13.5675 23.1181 16.5167C21.9204 19.4658 19.6 21.8185 16.6674 23.0571C15.1898 23.6824 13.6012 24.0031 11.9968 24V24ZM16.2019 8.75193C15.5618 8.76394 14.9396 8.96469 14.4132 9.32898C13.8868 9.69328 13.4797 10.2049 13.243 10.7996C13.0064 11.3944 12.9506 12.0458 13.0829 12.672C13.2151 13.2983 13.5293 13.8716 13.9862 14.32C14.4431 14.7684 15.0222 15.0719 15.6509 15.1924C16.2797 15.3129 16.93 15.2451 17.5204 14.9975C18.1107 14.7498 18.6147 14.3334 18.9692 13.8004C19.3237 13.2674 19.5129 12.6416 19.513 12.0015C19.5035 11.132 19.1497 10.3018 18.529 9.69266C17.9084 9.08355 17.0716 8.74526 16.2019 8.75193V8.75193ZM7.80709 8.75193C7.16718 8.76463 6.54526 8.96595 6.01933 9.33066C5.49341 9.69536 5.08688 10.2072 4.85075 10.802C4.61462 11.3968 4.55939 12.048 4.69198 12.6741C4.82458 13.3001 5.1391 13.8731 5.5961 14.3211C6.0531 14.7692 6.63224 15.0723 7.26088 15.1926C7.88952 15.3128 8.53967 15.2448 9.1298 14.9971C9.71994 14.7493 10.2238 14.3329 10.5781 13.8C10.9325 13.2671 11.1216 12.6414 11.1217 12.0015C11.1126 11.1313 10.7584 10.3003 10.1369 9.69097C9.51543 9.08167 8.67747 8.74393 7.80709 8.75193V8.75193Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Linkedin' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Linkedin', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24V24ZM14.1866 11.8931C14.8151 11.8931 15.5647 12.2135 15.5647 13.7398V18.1108H18.2842V13.4264C18.3499 12.4199 18.0301 11.4261 17.3897 10.6467C17.1015 10.3475 16.7532 10.1126 16.3677 9.95754C15.9823 9.80245 15.5683 9.73065 15.1532 9.74686C14.5743 9.73037 14.0044 9.89311 13.5216 10.2128C13.1924 10.4498 12.9138 10.7502 12.7021 11.0962V9.94083H9.98203C10.0175 10.6987 9.98203 18.0363 9.98203 18.1103H12.7021V13.5484C12.6902 13.3237 12.7206 13.0989 12.7916 12.8854C12.8953 12.6216 13.0636 12.388 13.2811 12.206C13.5368 11.9982 13.8576 11.8872 14.1871 11.8926L14.1866 11.8931ZM5.75743 9.94033V18.1108H8.4765V9.94033H5.75743ZM7.13496 6.00235C6.94066 5.98504 6.74487 6.00805 6.55988 6.06995C6.37489 6.13184 6.20468 6.23129 6.05994 6.36205C5.91519 6.49281 5.79903 6.65206 5.71873 6.82981C5.63844 7.00757 5.59574 7.2 5.59333 7.39503C5.59091 7.59006 5.62882 7.78348 5.70468 7.96317C5.78055 8.14287 5.89272 8.30495 6.03418 8.43925C6.17564 8.57356 6.34333 8.67719 6.52673 8.74366C6.71013 8.81012 6.90529 8.83798 7.09996 8.82548H7.11746C7.53193 8.84057 7.9358 8.69268 8.24249 8.41353C8.37582 8.28377 8.48127 8.12816 8.55237 7.95624C8.62347 7.78431 8.65873 7.59969 8.656 7.41367C8.65674 7.2187 8.61704 7.0257 8.5394 6.84685C8.46177 6.66801 8.34789 6.50719 8.20496 6.37457C8.06203 6.24195 7.89315 6.1404 7.70898 6.07634C7.52481 6.01227 7.32936 5.98708 7.13496 6.00235V6.00235Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Youtube' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Youtube', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24ZM11.9966 7.00222C11.9526 7.00222 7.60648 7.00572 6.52695 7.30218C6.22735 7.38689 5.95529 7.54883 5.738 7.77179C5.52072 7.99474 5.36585 8.27087 5.28892 8.57251C5.08786 9.71493 4.98997 10.8731 4.99641 12.0331C4.98983 13.1927 5.08756 14.3505 5.28842 15.4926C5.36526 15.7943 5.52009 16.0705 5.73739 16.2934C5.95469 16.5164 6.22681 16.6783 6.52645 16.7629C7.60398 17.0599 11.9521 17.0629 11.9961 17.0629C12.0401 17.0629 16.3877 17.0594 17.4657 16.7629C17.7653 16.6784 18.0375 16.5165 18.2547 16.2935C18.4719 16.0706 18.6266 15.7943 18.7032 15.4926C18.905 14.3506 19.0032 13.1927 18.9967 12.0331C19.0034 10.8732 18.9053 9.7152 18.7037 8.57301C18.6268 8.2714 18.472 7.99528 18.2548 7.77226C18.0376 7.54924 17.7657 7.38715 17.4662 7.30218C16.3867 7.00522 12.0401 7.00222 11.9966 7.00222ZM10.8055 14.3088V10.2163L14.0801 12.2625L10.8066 14.3088H10.8055Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Vimeo' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Vimeo', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24V24ZM6.20394 10.3458C6.69545 10.3458 7.16246 11.1277 7.59197 12.6695L8.17249 14.8012L8.7535 16.9319C9.33102 18.4737 10.048 19.2556 10.8841 19.2556C11.7204 19.1907 12.513 18.8556 13.1421 18.3007C14.1618 17.464 15.0725 16.5026 15.8527 15.4391C17.7377 13.0139 18.7257 11.0777 18.7892 9.68287C18.8392 8.6395 18.6392 7.87011 18.1982 7.39667C18.0014 7.20145 17.7669 7.04833 17.5091 6.94666C17.2512 6.84498 16.9753 6.79686 16.6982 6.80525C16.6447 6.80525 16.5907 6.80275 16.5377 6.80275C15.6593 6.77746 14.8026 7.07846 14.1331 7.64764C13.409 8.33714 12.8926 9.21575 12.6426 10.1838C12.9783 10.0338 13.341 9.95354 13.7086 9.94783C13.8475 9.93639 13.9873 9.95474 14.1185 10.0016C14.2497 10.0485 14.3695 10.1229 14.4696 10.2198C14.5695 10.3566 14.6397 10.5129 14.6756 10.6784C14.7115 10.844 14.7124 11.0152 14.6781 11.1812C14.5128 11.9663 14.1823 12.7072 13.7086 13.3549C13.1086 14.3048 12.6511 14.7832 12.3506 14.7832C11.9646 14.7832 11.6056 14.0428 11.2836 12.5835C11.1761 12.156 10.9801 11.0462 10.701 9.28392C10.6357 8.66114 10.4119 8.06546 10.051 7.55365C9.90714 7.36922 9.7221 7.22099 9.5107 7.12082C9.29929 7.02065 9.06738 6.9713 8.8335 6.97672C8.768 6.97672 8.6995 6.98022 8.631 6.98672C8.15849 7.02972 7.44047 7.46466 6.49645 8.27955C5.83343 8.87947 5.12642 9.51089 4.3964 10.1533L5.07342 11.0252C5.41417 10.7435 5.79525 10.5145 6.20394 10.3458Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Twitch' === $active_site ) {
					?>
					<div class="social-links">
						<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Twitch', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
							<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
								<path fill-rule="evenodd" clip-rule="evenodd" d="M17.3846 13.5714L15.2308 15.7143H12L9.84615 17.8571V15.7143H7.15385V6.60715H17.3846V13.5714ZM14.1538 8.71652H15.7692V13.0357H14.1538V8.71652ZM12 8.71652H10.3846V13.0357H12V8.71652Z" fill="white"/>
								<path fill-rule="evenodd" clip-rule="evenodd" d="M12 24C18.6274 24 24 18.6274 24 12C24 5.37259 18.6274 0 12 0C5.37258 0 0 5.37259 0 12C0 18.6274 5.37258 24 12 24ZM6.07692 5L5 7.67856V17.8571H8.23077V20H10.3846L12.5385 17.8571H15.2308L19 14.1071V5H6.07692Z" fill="white"/>
							</svg>
						</a>
					</div>
					<?php
			} else if ( 'Discord' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Discord', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24V24ZM16.2162 14.5552C16.2796 14.5551 16.3416 14.5744 16.3939 14.6104C16.4461 14.6464 16.4862 14.6975 16.5087 14.7568C16.5312 14.8161 16.5352 14.8809 16.52 14.9425C16.5048 15.0041 16.4712 15.0596 16.4237 15.1017C15.723 15.6435 14.9113 16.024 14.0466 16.216L14.6196 17.0009C14.6488 17.0406 14.687 17.0728 14.7309 17.095C14.7748 17.1172 14.8234 17.1288 14.8726 17.1289H14.8821C15.4477 17.1104 17.9297 16.6904 18.8367 15.0957C18.8638 15.0485 18.8781 14.9951 18.8782 14.9407C18.846 13.396 18.5959 11.8636 18.1352 10.3888C17.7382 9.08895 17.2352 8.00209 16.8852 7.67863C15.6102 6.65227 13.6076 6.50279 13.5851 6.50179H13.5596C13.4997 6.50183 13.4411 6.51923 13.3909 6.55188C13.3406 6.58453 13.301 6.63104 13.2766 6.68576C13.239 6.7702 13.2071 6.85705 13.1811 6.94573C14.1531 7.09323 15.0872 7.42842 15.9312 7.9326C16.0017 7.97635 16.0519 8.04631 16.0708 8.12708C16.0897 8.20785 16.0757 8.29282 16.0319 8.36329C15.9882 8.43376 15.9182 8.48397 15.8374 8.50286C15.7566 8.52175 15.6716 8.50778 15.6012 8.46403C14.4056 7.79219 13.0573 7.43929 11.6858 7.43929C10.3144 7.43929 8.96602 7.79219 7.77048 8.46403C7.7 8.50778 7.61502 8.52175 7.53423 8.50286C7.45345 8.48397 7.38348 8.43376 7.33972 8.36329C7.29596 8.29282 7.28199 8.20785 7.30088 8.12708C7.31978 8.04631 7.36999 7.97635 7.44047 7.9326C8.2845 7.42887 9.21858 7.09435 10.1905 6.94773C10.164 6.86024 10.1335 6.77475 10.1 6.69426L10.0965 6.68626C10.0725 6.63173 10.0331 6.58534 9.98327 6.55269C9.9334 6.52004 9.87514 6.50253 9.81553 6.50229H9.78703C9.76703 6.50229 7.74898 6.66527 6.47245 7.69263C5.81343 8.30205 4.4964 11.8666 4.4964 14.9427C4.49647 14.9971 4.51097 15.0506 4.5384 15.0977C5.44543 16.6924 7.92698 17.1124 8.4925 17.1309H8.502C8.55151 17.1307 8.60028 17.1189 8.64434 17.0963C8.6884 17.0737 8.72649 17.041 8.7555 17.0009L9.32702 16.2145C8.46291 16.0226 7.65178 15.6424 6.95146 15.1012C6.919 15.0745 6.89223 15.0416 6.87277 15.0043C6.8533 14.9671 6.84152 14.9264 6.83814 14.8845C6.83476 14.8426 6.83985 14.8005 6.85309 14.7606C6.86634 14.7208 6.88748 14.684 6.91524 14.6525C6.94301 14.621 6.97684 14.5953 7.01471 14.5772C7.05259 14.559 7.09373 14.5486 7.1357 14.5467C7.17767 14.5448 7.21959 14.5513 7.25898 14.5659C7.29837 14.5805 7.33442 14.6029 7.36497 14.6317C7.70005 14.8927 8.0704 15.105 8.465 15.2621C9.48687 15.6838 10.5837 15.8938 11.6891 15.8795C14.4856 15.8795 15.9507 14.6832 16.0112 14.6297C16.0683 14.581 16.1411 14.5544 16.2162 14.5547V14.5552ZM13.7196 13.6923C13.4094 13.67 13.1204 13.5263 12.9155 13.2923C12.7106 13.0583 12.6063 12.7529 12.6251 12.4425C12.6063 12.1321 12.7106 11.8267 12.9155 11.5927C13.1204 11.3588 13.4094 11.215 13.7196 11.1927C14.0298 11.2151 14.3186 11.3589 14.5234 11.5929C14.7282 11.8269 14.8325 12.1321 14.8136 12.4425C14.8325 12.7529 14.7282 13.0581 14.5234 13.2921C14.3186 13.5261 14.0298 13.6699 13.7196 13.6923V13.6923ZM9.65502 13.6923C9.34477 13.67 9.05584 13.5263 8.85093 13.2923C8.64602 13.0583 8.54166 12.7529 8.5605 12.4425C8.54166 12.1321 8.64602 11.8267 8.85093 11.5927C9.05584 11.3588 9.34477 11.215 9.65502 11.1927C9.96519 11.2151 10.254 11.3589 10.4588 11.5929C10.6636 11.8269 10.7679 12.1321 10.749 12.4425C10.7679 12.7528 10.6637 13.058 10.459 13.2919C10.2543 13.5259 9.9656 13.6698 9.65552 13.6923H9.65502Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Whatsapp' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Whatsapp', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9956 24C9.22708 23.9979 6.54439 23.0391 4.40188 21.2862C2.25936 19.5332 0.78872 17.0938 0.239027 14.3811C-0.310665 11.6683 0.0943811 8.84899 1.38557 6.40059C2.67675 3.95219 4.7747 2.02521 7.32411 0.94602C10.2569 -0.292643 13.5618 -0.315796 16.5117 0.881653C19.4615 2.0791 21.8148 4.39907 23.0538 7.33118C24.2927 10.2633 24.3159 13.5674 23.1181 16.5165C21.9204 19.4657 19.5999 21.8184 16.6671 23.0571C15.1892 23.6824 13.6004 24.0031 11.9956 24ZM11.8756 4.40256C10.5912 4.40336 9.32953 4.74184 8.21728 5.38407C7.10503 6.02629 6.18128 6.94966 5.53871 8.06154C4.89614 9.17341 4.55735 10.4347 4.55633 11.7188C4.55532 13.0029 4.89211 14.2647 5.53292 15.3776L4.49481 19.1691L8.37472 18.1507C9.44829 18.7342 10.6506 19.0403 11.8726 19.0411H11.8756C13.8069 19.0252 15.6537 18.247 17.0137 16.876C18.3737 15.505 19.1368 13.6523 19.1368 11.7213C19.1368 9.79043 18.3737 7.93773 17.0137 6.56673C15.6537 5.19574 13.8069 4.41752 11.8756 4.40156V4.40256Z" fill="white"/>
							<path d="M11.8956 18.0008C10.7761 18.0006 9.67722 17.6998 8.71375 17.1299L8.48573 16.9944L6.11798 17.6148L6.74905 15.3096L6.59903 15.0732C5.86248 13.8996 5.53686 12.5147 5.67337 11.136C5.80987 9.75734 6.40075 8.4631 7.35313 7.45673C8.30551 6.45036 9.56539 5.78892 10.9347 5.57639C12.3041 5.36386 13.7052 5.61228 14.918 6.28261C16.1307 6.95294 17.0863 8.00716 17.6344 9.27958C18.1826 10.552 18.2923 11.9704 17.9463 13.312C17.6003 14.6535 16.8182 15.8421 15.7229 16.6908C14.6276 17.5395 13.2813 18.0003 11.8956 18.0008ZM9.23331 8.27755C9.1382 8.27983 9.04461 8.3019 8.95852 8.34236C8.87242 8.38282 8.7957 8.44077 8.73325 8.51252L8.69525 8.55202C8.49263 8.75047 8.33298 8.98846 8.22623 9.2512C8.11947 9.51393 8.06789 9.79581 8.07469 10.0793C8.13174 10.7873 8.39785 11.4625 8.83927 12.0191V12.0221C8.84577 12.0306 8.85727 12.0471 8.87377 12.0721C9.66858 13.2642 10.7641 14.2255 12.0496 14.8587C12.3996 15.0094 12.7573 15.1416 13.1212 15.2546C13.3567 15.3291 13.6023 15.3664 13.8493 15.3651C14.0018 15.3645 14.1541 15.3524 14.3048 15.3291C14.5665 15.2762 14.8144 15.1695 15.0327 15.0158C15.251 14.8621 15.435 14.6648 15.573 14.4362C15.6958 14.1557 15.7339 13.8453 15.6825 13.5434C15.6126 13.4654 15.5237 13.407 15.4245 13.3739L15.3244 13.3239C15.0999 13.2119 14.2088 12.774 14.0408 12.713C13.9774 12.6853 13.9098 12.6684 13.8408 12.663C13.7945 12.6648 13.7496 12.679 13.7106 12.704C13.6717 12.7291 13.6401 12.7641 13.6193 12.8055C13.4938 12.9939 13.1392 13.4109 13.0247 13.5419C13.0014 13.574 12.971 13.6004 12.9359 13.6191C12.9008 13.6377 12.8619 13.6481 12.8222 13.6493C12.7503 13.6452 12.6803 13.6245 12.6177 13.5889C12.5872 13.5734 12.5462 13.5559 12.4941 13.5334C11.9855 13.3213 11.5163 13.0248 11.1065 12.6565C10.6956 12.2774 10.3434 11.8393 10.0614 11.3566C9.95038 11.1657 10.0534 11.0637 10.1439 10.9732C10.1999 10.9177 10.2654 10.8377 10.3284 10.7607C10.3614 10.7207 10.3939 10.6807 10.4254 10.6442C10.4913 10.5661 10.5456 10.4789 10.5864 10.3853L10.6135 10.3308C10.638 10.2788 10.6492 10.2215 10.6461 10.164C10.6429 10.1066 10.6255 10.0509 10.5954 10.0018C10.5639 9.93933 10.3849 9.50189 10.2264 9.11694V9.11344C10.1454 8.91697 10.0684 8.73149 10.0164 8.60651C9.89238 8.30955 9.76636 8.28455 9.65285 8.28455H9.59534C9.48083 8.27855 9.35382 8.27755 9.23331 8.27755Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Telegram' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Telegram', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
						<path fill-rule="evenodd" clip-rule="evenodd" d="M4.40235 21.2871C6.54514 23.04 9.22812 23.9984 11.9967 24C13.6012 24.003 15.1898 23.6824 16.6674 23.0571C19.6 21.8185 21.9204 19.4658 23.1181 16.5167C24.3158 13.5675 24.2927 10.2635 23.0539 7.33136C21.8151 4.39924 19.4621 2.07924 16.5124 0.881736C13.5628 -0.315765 10.2582 -0.292675 7.32557 0.945927C4.77584 2.02472 2.67748 3.95161 1.38599 6.40016C0.0944965 8.84871 -0.310715 11.6684 0.239001 14.3814C0.788718 17.0945 2.25956 19.5341 4.40235 21.2871ZM12.3428 8.682C11.0577 9.18145 8.48921 10.2152 4.63745 11.7832C4.24678 12.0253 4.03653 12.2575 4.0067 12.4798C3.94944 12.9066 4.25488 13.0249 5.08232 13.2763C5.75694 13.4812 6.66442 13.7209 7.13618 13.7304C7.56411 13.739 8.04173 13.5742 8.56904 13.2359C12.1679 10.966 14.0256 9.8187 14.1422 9.79396C14.2245 9.77651 14.3385 9.75457 14.4158 9.81873C14.493 9.88289 14.5917 10.2084 14.5969 10.2414C14.6078 10.3106 12.6829 12.0777 11.6781 13.0001C11.3633 13.2891 11.1389 13.4952 11.0925 13.5402C10.9284 13.6994 10.7446 13.8418 10.5718 13.9757C9.96179 14.4483 9.48907 14.8146 10.5057 15.4405C11.074 15.7905 11.5346 16.0476 12.0002 16.3075C12.4593 16.5638 12.9233 16.8229 13.5006 17.1765C13.5811 17.2257 13.6597 17.2747 13.7368 17.3228C14.3716 17.7184 14.9069 18.0521 15.5911 17.9932C15.9441 17.9629 16.3115 17.7649 16.4967 16.8397C16.9344 14.6533 17.7948 9.91606 17.9936 7.96395C18.011 7.79292 17.9891 7.57404 17.9715 7.47795C17.9539 7.38187 17.9172 7.24496 17.7835 7.14362C17.6252 7.0236 17.3808 6.99829 17.2715 7.00009C16.7745 7.00827 16.0121 7.25598 12.3428 8.682Z" fill="white"/>
					</svg>
					</a>
				</div>
				<?php
			} else if ( 'Signal' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Signal', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
						<path fill-rule="evenodd" clip-rule="evenodd" d="M12 24C18.6274 24 24 18.6274 24 12C24 5.37259 18.6274 0 12 0C5.37258 0 0 5.37259 0 12C0 18.6274 5.37258 24 12 24ZM10.26 4.96136L10.08 4.23392C9.29971 4.4259 8.55293 4.73477 7.865 5.15005L8.25 5.79254C8.87425 5.41571 9.55192 5.13547 10.26 4.96136ZM13.74 4.96136L13.92 4.23392C14.7012 4.42566 15.4488 4.73453 16.1375 5.15005L15.75 5.79254C15.1257 5.41571 14.4481 5.13547 13.74 4.96136ZM4.23375 10.0797C4.42576 9.29944 4.73467 8.5527 5.15 7.86487L5.7925 8.24985C5.41565 8.87405 5.13539 9.55164 4.96125 10.2597L4.23375 10.0797ZM4.83125 10.9134C4.77688 11.2729 4.74975 11.636 4.75 11.9995C4.74976 12.3631 4.77692 12.7262 4.83125 13.0857L4.09 13.1982C3.97 12.4036 3.97 11.5955 4.09 10.8009L4.83125 10.9134ZM15.75 18.2065L16.135 18.8491C15.4478 19.2641 14.7019 19.573 13.9225 19.7652L13.7425 19.0378C14.4497 18.8634 15.1265 18.5832 15.75 18.2065ZM19.1687 13.0857C19.2231 12.7262 19.2503 12.3631 19.25 11.9995C19.2502 11.636 19.2231 11.2729 19.1687 10.9134L19.91 10.8009C20.03 11.5955 20.03 12.4036 19.91 13.1982L19.1687 13.0857ZM19.0387 13.7394L19.7663 13.9194C19.5745 14.7005 19.2656 15.4481 18.85 16.1367L18.2075 15.7492C18.5844 15.1251 18.8646 14.4474 19.0387 13.7394ZM10.8012 19.9102L10.9137 19.1689C11.6339 19.2773 12.3661 19.2773 13.0863 19.1689L13.1987 19.9102C12.4041 20.0302 11.5959 20.0302 10.8012 19.9102ZM16.3 17.8353C16.886 17.4034 17.4038 16.886 17.8363 16.3004L18.44 16.7491C17.9628 17.3941 17.3914 17.9637 16.745 18.439L16.3 17.8353ZM17.8363 7.69986C17.4039 7.11383 16.8861 6.59601 16.3 6.16373L16.75 5.56012C17.3946 6.03571 17.9643 6.60529 18.44 7.24985L17.8363 7.69986ZM7.7 6.16373C7.11393 6.59601 6.59608 7.11383 6.16375 7.69986L5.56 7.24991C6.03568 6.60532 6.60535 6.03568 7.25 5.56006L7.7 6.16373ZM18.2075 8.24985L18.85 7.86487C19.2651 8.55194 19.574 9.29779 19.7663 10.0772L19.0387 10.2572C18.8644 9.55002 18.5841 8.87326 18.2075 8.24985ZM13.0863 4.83142C12.3661 4.72308 11.6339 4.72308 10.9137 4.83142L10.8012 4.09018C11.5959 3.97018 12.4041 3.97018 13.1987 4.09018L13.0863 4.83142ZM5 18.9991L6.54875 18.6378L6.71875 19.3739L5.17125 19.7289C5.047 19.7581 4.91738 19.755 4.79465 19.72C4.67192 19.6851 4.56014 19.6194 4.4699 19.5291C4.37966 19.4389 4.31393 19.3271 4.27895 19.2044C4.24397 19.0817 4.24089 18.9521 4.27 18.8278L4.63125 17.2791L5.36125 17.4503L5 18.9991ZM5.5175 16.7804L4.7875 16.6104L4.97125 15.8205C4.64472 15.2211 4.39684 14.5822 4.23375 13.9194L4.96125 13.7394C5.13142 14.4314 5.40311 15.0944 5.7675 15.7067L5.5175 16.7804ZM7.21375 18.4853L8.2875 18.2353L8.2925 18.2303C8.90311 18.5959 9.56442 18.8693 10.255 19.0415L10.075 19.7689C9.41219 19.6059 8.77317 19.358 8.17375 19.0316L7.38375 19.2153L7.21375 18.4853ZM6.31344 8.85736C7.45688 6.78711 9.63481 5.50128 12 5.50006C14.7637 5.4978 17.2269 7.24329 18.1402 9.85175C19.0535 12.4601 18.2174 15.3607 16.0558 17.0829C13.8942 18.805 10.8799 18.972 8.54125 17.4991L5.875 18.1241L6.5 15.458C5.24144 13.4556 5.17 10.9277 6.31344 8.85736Z" fill="white"/>
					</svg>
					</a>
				</div>
				<?php
			} else if ( 'Snapchat' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Snapchat', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
						<path d="M17.8818 16.6797C18.1402 16.61 18.4466 16.5273 18.8222 16.3166C19.2581 16.0722 19.0097 15.9214 18.869 15.85C16.3908 14.6328 15.9954 12.7506 15.9782 12.6094L15.9763 12.5947C15.9552 12.4318 15.9382 12.3013 16.1158 12.1349C16.2361 12.0213 16.6394 11.756 16.9528 11.5497C17.0994 11.4533 17.2263 11.3698 17.2955 11.3208C17.6549 11.0653 17.8143 10.8098 17.6971 10.4955C17.6158 10.2797 17.4158 10.1972 17.2049 10.1972C17.1393 10.1972 17.0721 10.2051 17.008 10.2194C16.7754 10.2708 16.5467 10.3616 16.3525 10.4388C16.2166 10.4927 16.0977 10.54 16.0064 10.5622C15.9884 10.567 15.9711 10.5701 15.955 10.5717C15.9444 10.5728 15.9344 10.5733 15.9251 10.5733C15.8079 10.5733 15.7642 10.5193 15.7735 10.3749L15.7766 10.3283C15.8056 9.87668 15.8587 9.05089 15.7923 8.27693C15.6985 7.17398 15.3485 6.62805 14.9329 6.1456C14.7329 5.91391 13.8 4.90776 12.003 4.90776C10.2107 4.90776 9.27316 5.91391 9.07315 6.1456C8.6575 6.62964 8.30748 7.17557 8.21373 8.27693C8.15117 9.00618 8.19728 9.78145 8.22495 10.2464C8.22768 10.2924 8.23022 10.3353 8.23248 10.3749C8.2403 10.513 8.19966 10.5733 8.0809 10.5733C8.05746 10.5733 8.0309 10.5701 7.99965 10.5622C7.90829 10.54 7.78938 10.4927 7.65349 10.4388C7.45935 10.3616 7.23059 10.2708 6.99803 10.2194C6.93396 10.2051 6.86678 10.1972 6.80115 10.1972C6.59019 10.1972 6.39018 10.2781 6.30893 10.4955C6.19174 10.8098 6.34956 11.0653 6.71051 11.3208C6.77969 11.3698 6.90656 11.4533 7.05307 11.5497C7.36656 11.7559 7.76994 12.0213 7.89027 12.1349C8.06793 12.303 8.05081 12.4336 8.02963 12.5952L8.02779 12.6094C8.00903 12.7506 7.61525 14.6328 5.13698 15.85C4.99167 15.9214 4.74478 16.0722 5.18074 16.3166C5.55461 16.5255 5.85994 16.608 6.11761 16.6776C6.33165 16.7354 6.51279 16.7844 6.67302 16.8895C6.83536 16.996 6.85815 17.1689 6.8793 17.3293C6.89723 17.4654 6.91399 17.5925 7.01366 17.6624C7.12968 17.7444 7.34502 17.7528 7.63533 17.7641C8.01358 17.7788 8.5191 17.7985 9.09816 17.9925C9.38725 18.0894 9.63841 18.2461 9.90294 18.4111C10.4219 18.7348 10.9923 19.0907 12.0014 19.0907C13.0117 19.0907 13.5887 18.7312 14.1097 18.4067C14.3728 18.2428 14.6216 18.0878 14.9047 17.9925C15.4838 17.7985 15.9889 17.7788 16.367 17.7641C16.6572 17.7528 16.8725 17.7444 16.9892 17.6624C17.0889 17.5925 17.1057 17.4654 17.1236 17.3293C17.1447 17.1689 17.1675 16.996 17.3299 16.8895C17.4892 16.7857 17.6693 16.7371 17.8818 16.6797Z" fill="white"/>
						<path fill-rule="evenodd" clip-rule="evenodd" d="M12 24C18.6274 24 24 18.6274 24 12C24 5.37259 18.6274 0 12 0C5.37259 0 0 5.37259 0 12C0 18.6274 5.37259 24 12 24ZM19.3784 15.0978C19.6191 15.2343 19.8316 15.3977 19.9425 15.7056C20.0676 16.05 19.991 16.4388 19.6894 16.7721L19.6847 16.7768C19.5738 16.9022 19.4347 17.0117 19.255 17.1117C18.8503 17.3386 18.5081 17.4481 18.2409 17.5227C18.1893 17.5386 18.094 17.5719 18.0502 17.61C17.9894 17.6637 17.9639 17.7319 17.932 17.8171C17.9083 17.8806 17.8811 17.9536 17.833 18.0369C17.7299 18.2178 17.5986 18.3368 17.4955 18.4098C17.1652 18.6409 16.7961 18.6557 16.4036 18.6716L16.4001 18.6717L16.3973 18.6718C16.0433 18.6861 15.6411 18.7023 15.1829 18.8558C15.0048 18.9156 14.815 19.0331 14.5966 19.1683L14.5735 19.1827L14.5684 19.1859C14.0141 19.53 13.257 20 11.9983 20C10.7373 20 9.98257 19.5303 9.43256 19.1859C9.20441 19.043 9.00597 18.9193 8.81532 18.8558C8.35715 18.7023 7.95494 18.6861 7.60091 18.6718L7.59807 18.6717L7.59427 18.6716C7.20192 18.6557 6.83134 18.6408 6.50269 18.4098C6.41206 18.3464 6.30267 18.248 6.20737 18.1035C6.13051 17.9907 6.09515 17.8952 6.0654 17.8148C6.03404 17.7301 6.0089 17.6622 5.94797 17.6084C5.90109 17.5656 5.79327 17.5307 5.7464 17.5164C5.48076 17.4418 5.14323 17.3323 4.74634 17.1101C4.57758 17.0149 4.44319 16.9117 4.33694 16.7959C4.01349 16.4578 3.92911 16.0563 4.05724 15.704C4.20117 15.3061 4.51332 15.1471 4.84151 14.98C4.89812 14.9511 4.9552 14.9221 5.01198 14.8915C5.73859 14.4916 6.30893 13.9901 6.70738 13.3981C6.84177 13.1982 6.93709 13.0173 7.00272 12.8697C7.04178 12.7617 7.04178 12.703 7.01521 12.6491C6.99178 12.6015 6.92459 12.5507 6.90584 12.538C6.83533 12.4905 6.7643 12.4431 6.70009 12.4005C6.65047 12.3676 6.6049 12.3375 6.56676 12.3126C6.40581 12.2079 6.27924 12.1238 6.19643 12.0651C5.8886 11.8461 5.67139 11.6128 5.537 11.3525C5.34637 10.9859 5.32294 10.567 5.46982 10.1734C5.67296 9.62746 6.18236 9.28784 6.79802 9.28784C6.92459 9.28784 7.05585 9.30212 7.18398 9.33069C7.2003 9.33464 7.21703 9.33859 7.23375 9.34254C7.25063 9.34653 7.2675 9.35051 7.28398 9.35449C7.2793 8.98314 7.28711 8.5864 7.31993 8.19917C7.43556 6.83437 7.9059 6.11862 8.39655 5.5489C8.59969 5.31244 8.95596 4.9633 9.49348 4.65225C10.2388 4.21901 11.0826 4 11.9999 4C12.9203 4 13.7641 4.21901 14.5094 4.65384C15.0438 4.96489 15.4001 5.31244 15.6048 5.55049C16.0954 6.12021 16.5658 6.83595 16.6814 8.20076C16.7142 8.58798 16.7236 8.98473 16.7173 9.35608C16.7498 9.34822 16.7833 9.34013 16.8174 9.33228C16.9455 9.30371 17.0752 9.28943 17.2033 9.28943C17.819 9.28943 18.3284 9.62904 18.5315 10.175C18.6784 10.5685 18.655 10.9875 18.4643 11.3541C18.3299 11.6144 18.1143 11.8477 17.8049 12.0667C17.7336 12.1168 17.6261 12.1878 17.492 12.2763L17.4346 12.3142C17.3439 12.3729 17.2111 12.4602 17.0814 12.5475C17.0533 12.5681 17.0033 12.6094 16.9846 12.6491C16.9595 12.7014 16.958 12.7586 16.9924 12.8602C17.0596 13.0109 17.1549 13.195 17.2924 13.3997C17.6987 14.0044 18.2862 14.5154 19.0378 14.9201C19.0672 14.9353 19.0965 14.9503 19.1258 14.9652C19.1697 14.9876 19.2134 15.0099 19.2566 15.0327C19.2909 15.0486 19.3331 15.0708 19.3784 15.0978Z" fill="white"/>
					</svg>
					</a>
				</div>
				<?php
			} else if ( 'Viber' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Viber', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path fill-rule="evenodd" clip-rule="evenodd" d="M18.395 13.7197C18.0324 16.6472 16.0676 17.1044 15.3596 17.2691C15.3315 17.2757 15.3053 17.2817 15.2813 17.2875C15.2386 17.2978 15.2027 17.307 15.1747 17.316C14.9881 17.376 13.254 17.8074 11.0733 17.665C11.0733 17.665 9.44841 19.6253 8.94087 20.135C8.86165 20.2148 8.76849 20.2469 8.70631 20.2311C8.61893 20.2097 8.59491 20.1062 8.59587 19.955L8.6098 17.2776C5.53937 16.4251 5.61098 13.298 5.65161 11.5231L5.65555 11.346C5.69156 9.61044 6.01759 8.18866 6.9861 7.23239C8.72624 5.65622 12.311 5.89175 12.311 5.89175C15.3382 5.90497 16.7888 6.81656 17.1251 7.12195C18.242 8.07822 18.811 10.3674 18.395 13.7197ZM12.4309 9.94113C12.437 9.82507 12.5359 9.7359 12.652 9.74197C13.071 9.76382 13.4206 9.89072 13.6699 10.1485C13.9182 10.4052 14.0395 10.7634 14.0608 11.1923C14.0665 11.3083 13.9771 11.4071 13.861 11.4129C13.7449 11.4186 13.6462 11.3292 13.6404 11.2131C13.6223 10.8483 13.5223 10.6012 13.3674 10.441C13.2135 10.2819 12.9781 10.1804 12.6301 10.1622C12.514 10.1562 12.4249 10.0572 12.4309 9.94113ZM12.3493 8.65613C12.2334 8.64764 12.1326 8.73471 12.1241 8.85062C12.1156 8.96652 12.2027 9.06735 12.3186 9.07584C13.0877 9.13211 13.6644 9.38943 14.0767 9.83954C14.4904 10.2916 14.6936 10.8551 14.6786 11.5463C14.6761 11.6625 14.7682 11.7587 14.8844 11.7612C15.0006 11.7637 15.0968 11.6716 15.0993 11.5554C15.1164 10.7677 14.8815 10.0955 14.387 9.55527C13.887 9.00949 13.2008 8.71844 12.3493 8.65613ZM11.7668 7.81464C11.7676 7.69843 11.8624 7.60489 11.9786 7.60568C13.1551 7.61389 14.15 8.00562 14.9487 8.78424C15.7543 9.56958 16.1523 10.6386 16.1624 11.9651C16.1633 12.0813 16.0698 12.1762 15.9536 12.1771C15.8374 12.178 15.7425 12.0845 15.7416 11.9683C15.7322 10.7285 15.3634 9.77625 14.6549 9.08557C13.9395 8.38815 13.0512 8.03403 11.9757 8.02652C11.8595 8.02573 11.7659 7.93085 11.7668 7.81464ZM13.1188 13.7488C12.9656 13.9375 12.6811 13.9135 12.6811 13.9135C10.6017 13.3827 10.0452 11.2764 10.0452 11.2764C10.0452 11.2764 10.0202 10.9919 10.2099 10.8388L10.5856 10.5401C10.772 10.3965 10.8908 10.0482 10.7011 9.70798C10.5556 9.45261 10.3975 9.20468 10.2272 8.96515C10.0618 8.73923 9.67644 8.27658 9.675 8.27515C9.48918 8.05594 9.21596 8.00504 8.92786 8.15509C8.92699 8.15509 8.9258 8.15546 8.92464 8.15582C8.92357 8.15619 8.92255 8.15652 8.92186 8.15652C8.63531 8.32162 8.37694 8.53137 8.15646 8.77786C8.15503 8.78076 8.15358 8.78076 8.15215 8.78339C7.97417 8.9982 7.87228 9.20868 7.84651 9.41483C7.84354 9.43176 7.84164 9.44885 7.84084 9.466C7.84019 9.47964 7.84024 9.49335 7.84099 9.50702C7.84004 9.59811 7.8539 9.68878 7.88205 9.77542L7.89189 9.78214C7.98169 10.101 8.20641 10.632 8.69473 11.5175C8.97406 12.0296 9.2962 12.5172 9.65771 12.975C9.83885 13.2045 10.033 13.4235 10.2392 13.6307L10.2466 13.6382C10.2515 13.6431 10.2563 13.648 10.2613 13.6528L10.2834 13.6751L10.3276 13.7193C10.5348 13.9255 10.7537 14.1197 10.9832 14.3008C11.4411 14.6624 11.9288 14.9845 12.441 15.2638C13.3262 15.7521 13.8578 15.9768 14.1761 16.0666L14.1828 16.0765C14.2695 16.1047 14.3601 16.1187 14.4513 16.1178C14.4821 16.1193 14.513 16.1173 14.5435 16.112C14.7501 16.0875 14.9605 15.9858 15.1746 15.8069C15.1773 15.8054 15.1773 15.804 15.1802 15.8025C15.4267 15.582 15.6365 15.3236 15.8017 15.0371C15.8017 15.0364 15.802 15.0354 15.8023 15.0343C15.8026 15.0332 15.8029 15.032 15.8029 15.0311C15.953 14.743 15.9021 14.4698 15.6817 14.2838C15.6803 14.2838 15.2176 13.8977 14.9917 13.7316C14.7524 13.5613 14.5047 13.4031 14.2496 13.2576C13.9091 13.068 13.5615 13.1868 13.4174 13.3731L13.1188 13.7488Z" fill="white"/>
							<path fill-rule="evenodd" clip-rule="evenodd" d="M12 24C18.6274 24 24 18.6274 24 12C24 5.37259 18.6274 0 12 0C5.37259 0 0 5.37259 0 12C0 18.6274 5.37259 24 12 24ZM17.9599 6.31119C17.5623 5.94434 15.9557 4.77802 12.377 4.76215C12.377 4.76215 8.15675 4.50766 6.09947 6.39474C4.95427 7.54019 4.55139 9.21622 4.50891 11.2942C4.46642 13.3721 4.41142 17.2663 8.16516 18.3222H8.16876L8.16637 19.9334C8.16637 19.9334 8.14235 20.5857 8.57187 20.7187C9.00545 20.8533 9.28955 20.5303 9.65999 20.1091L9.72438 20.036C9.74582 20.0117 9.76758 19.9872 9.78969 19.9626C9.82304 19.9253 9.85721 19.8877 9.89233 19.8498C10.1646 19.5565 10.5406 19.1255 10.8239 18.7961C13.3911 19.0122 15.3656 18.5183 15.5898 18.4453C15.6016 18.4415 15.6146 18.4376 15.6289 18.4335L15.648 18.4281C15.6858 18.4177 15.7308 18.4062 15.7822 18.3932C16.6116 18.1823 19.0839 17.5538 19.5183 14.0076C20.0107 9.99408 19.2802 7.45544 17.9599 6.31119Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Codepen' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Codepen', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M12.0003 24C10.3975 24.0034 8.81001 23.6829 7.32916 23.0568C5.90779 22.4577 4.61269 21.5846 3.51459 20.4853C2.42204 19.3973 1.54845 18.1015 0.943047 16.6709C0.320892 15.1956 0 13.6062 0 11.9999C0 10.3936 0.320892 8.80423 0.943047 7.32894C1.54845 5.89838 2.42204 4.60258 3.51459 3.51454C4.61269 2.41524 5.90779 1.54217 7.32916 0.943012C10.3215 -0.314337 13.679 -0.314337 16.6713 0.943012C18.0926 1.54238 19.3875 2.41563 20.4854 3.51505C21.578 4.60309 22.4516 5.89889 23.057 7.32945C23.6791 8.80474 24 10.3941 24 12.0004C24 13.6067 23.6791 15.1961 23.057 16.6714C22.4516 18.102 21.578 19.3978 20.4854 20.4858C19.3875 21.5851 18.0925 22.4581 16.6713 23.0573C15.1905 23.6833 13.6029 24.0036 12.0003 24V24ZM12.0003 4.59605C11.873 4.5957 11.7485 4.63411 11.6427 4.70635L4.78662 9.3735C4.77562 9.38116 4.76762 9.3878 4.76162 9.39291L4.75512 9.39597L4.74712 9.40312L4.74162 9.40772L4.71062 9.43427C4.69039 9.45381 4.6712 9.47443 4.65311 9.49605C4.63474 9.5175 4.61802 9.54038 4.60311 9.56448C4.58899 9.58685 4.57613 9.61004 4.56461 9.63392V9.63852C4.55275 9.66477 4.5424 9.69171 4.53361 9.7192C4.52513 9.74757 4.51812 9.77637 4.51261 9.8055C4.50532 9.84371 4.50114 9.88248 4.50011 9.92141V14.5891C4.50032 14.6178 4.50232 14.6464 4.50611 14.6749C4.51511 14.7218 4.51861 14.7402 4.52261 14.7581V14.7652C4.53661 14.8092 4.54161 14.824 4.54761 14.8388C4.56861 14.8857 4.57511 14.8995 4.58361 14.9149C4.61061 14.9577 4.61961 14.9715 4.62911 14.9843C4.66212 15.0251 4.67262 15.0354 4.68362 15.0486C4.70333 15.0688 4.72402 15.0878 4.74562 15.1058C4.76512 15.1201 4.77362 15.1278 4.78062 15.1334L11.6362 19.8006C11.7419 19.873 11.8662 19.9118 11.9935 19.9118C12.1208 19.9118 12.2451 19.873 12.3508 19.8006L19.2069 15.1334L19.2184 15.1247L19.2469 15.1028L19.2629 15.089L19.2829 15.0716C19.3224 15.0313 19.3329 15.0206 19.3404 15.0098C19.3585 14.9882 19.3752 14.9653 19.3904 14.9414C19.4058 14.9179 19.4193 14.8931 19.4309 14.8674C19.4552 14.8142 19.4728 14.7581 19.4834 14.7004C19.4921 14.664 19.4978 14.6269 19.5004 14.5896V9.92141C19.5003 9.89272 19.4985 9.86407 19.4949 9.83562C19.4859 9.78813 19.4824 9.76975 19.4789 9.75188L19.4719 9.73197C19.4609 9.69877 19.4564 9.68499 19.4514 9.67222C19.4406 9.64621 19.4284 9.62082 19.4149 9.59614C19.4008 9.57179 19.3855 9.54827 19.3689 9.52567C19.3521 9.50308 19.3339 9.48159 19.3144 9.46133C19.2809 9.42865 19.2674 9.4164 19.2579 9.41027L19.2534 9.40618C19.2274 9.38678 19.2199 9.38065 19.2154 9.37708L12.3573 4.70635C12.2516 4.6342 12.1273 4.59581 12.0003 4.59605V4.59605ZM12.6448 18.0256V14.9562L15.4398 13.048L17.6959 14.5881L12.6453 18.0256H12.6448ZM11.3557 18.0256L6.30565 14.5875L8.56169 13.0475L11.3562 14.9557V18.0256H11.3557ZM12.0003 13.8129L9.72071 12.2555L12.0003 10.6976L14.2798 12.2555L12.0003 13.8124V13.8129ZM18.2114 13.3574L16.6003 12.2555L18.2129 11.1541V13.3574H18.2114ZM5.78914 13.3574V11.1541L7.40017 12.2555L5.78764 13.3564L5.78914 13.3574ZM15.4393 11.4635L12.6443 9.55427V6.48538L17.6944 9.92345L15.4388 11.464L15.4393 11.4635ZM8.56069 11.4635L6.30515 9.92243L11.3552 6.48436V9.55427L8.56119 11.463L8.56069 11.4635Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Patreon' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Patreon', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
						<path fill-rule="evenodd" clip-rule="evenodd" d="M24 12C24 18.6274 18.6274 24 12 24C5.37258 24 0 18.6274 0 12C0 5.37259 5.37258 0 12 0C18.6274 0 24 5.37259 24 12ZM15 16C17.7614 16 20 13.7614 20 11C20 8.23859 17.7614 6 15 6C12.2386 6 10 8.23859 10 11C10 13.7614 12.2386 16 15 16ZM6 6H9V19H6V6Z" fill="white"/>
					</svg>
					</a>
				</div>
				<?php
			} else if ( 'Spotify' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Spotify', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M12.0207 24C9.24637 23.9979 6.55807 23.0383 4.41108 21.2838C2.26408 19.5293 0.790368 17.0877 0.239527 14.3726C-0.311314 11.6574 0.0945783 8.8356 1.38846 6.38504C2.68234 3.93448 4.78468 2.0058 7.33941 0.925653C10.2753 -0.297075 13.5767 -0.308879 16.5213 0.892823C19.4659 2.09453 21.8139 4.4119 23.0518 7.33796C24.2896 10.264 24.3165 13.5605 23.1265 16.5063C21.9365 19.4521 19.6265 21.8074 16.7019 23.0568C15.2209 23.6825 13.6287 24.0033 12.0207 24V24ZM10.5454 15.2789C12.6325 15.237 14.6899 15.7777 16.4859 16.8401C16.6448 16.937 16.8358 16.967 17.0168 16.9234C17.1978 16.8797 17.354 16.7661 17.4511 16.6074C17.5481 16.4488 17.5781 16.2581 17.5344 16.0774C17.4907 15.8966 17.3769 15.7406 17.218 15.6437C15.2057 14.4462 12.8982 13.8341 10.556 13.8764C9.1154 13.8878 7.68066 14.0603 6.27859 14.3908C6.18876 14.4113 6.10385 14.4492 6.02871 14.5025C5.95358 14.5557 5.88969 14.6233 5.84069 14.7012C5.79169 14.7791 5.75854 14.8659 5.74314 14.9566C5.72774 15.0473 5.73039 15.1402 5.75093 15.2299C5.78687 15.3842 5.87381 15.5218 5.99773 15.6207C6.12165 15.7196 6.27532 15.7739 6.43393 15.7748C6.48706 15.7749 6.54003 15.7688 6.59178 15.7568C7.88772 15.4509 9.21384 15.2906 10.5454 15.2789V15.2789ZM10.3716 11.9669C12.9118 11.931 15.4152 12.5755 17.6214 13.8333C17.7196 13.8995 17.8301 13.9452 17.9464 13.9676C18.0627 13.99 18.1823 13.9886 18.2981 13.9637C18.4138 13.9387 18.5233 13.8906 18.62 13.8223C18.7166 13.7539 18.7985 13.6668 18.8605 13.566C18.9225 13.4653 18.9635 13.3531 18.981 13.2361C18.9985 13.1192 18.9921 12.9999 18.9622 12.8854C18.9323 12.771 18.8795 12.6638 18.807 12.5703C18.7345 12.4768 18.6439 12.3988 18.5404 12.3412C17.3497 11.625 16.059 11.0896 14.7106 10.7525C13.301 10.39 11.8511 10.2074 10.3956 10.2091C8.86988 10.1995 7.35107 10.4146 5.88824 10.8476C5.66543 10.9151 5.47862 11.0683 5.36891 11.2734C5.25919 11.4785 5.23556 11.7187 5.3032 11.9412C5.37085 12.1637 5.52423 12.3502 5.72961 12.4598C5.93499 12.5693 6.17555 12.5929 6.39835 12.5254C7.68866 12.1479 9.02705 11.9598 10.3716 11.9669V11.9669ZM10.6381 8.43729C13.8632 8.43729 16.8923 9.13782 18.9483 10.3557C19.11 10.4532 19.2952 10.505 19.484 10.5058C19.6667 10.5052 19.8461 10.4572 20.0047 10.3667C20.1633 10.2762 20.2957 10.1463 20.389 9.98946C20.4597 9.87078 20.5063 9.73934 20.5262 9.60265C20.546 9.46597 20.5386 9.32673 20.5045 9.19288C20.4704 9.05904 20.4102 8.93323 20.3273 8.82264C20.2445 8.71205 20.1406 8.61885 20.0217 8.54838C18.6382 7.75762 17.1388 7.18908 15.5785 6.86361C13.9539 6.51029 12.2958 6.33362 10.6331 6.33672C8.81471 6.3166 7.00266 6.55465 5.25134 7.04375C4.98395 7.1247 4.75971 7.3084 4.62796 7.55445C4.49621 7.80049 4.46773 8.08872 4.5488 8.35573C4.62987 8.62274 4.81384 8.84665 5.06024 8.97822C5.30664 9.10978 5.59529 9.13821 5.86268 9.05726C7.41718 8.62651 9.02502 8.41811 10.6381 8.43829V8.43729Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Anchor-Podcast' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Anchor-Podcast', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24V24ZM13.5996 4.50255L12.8996 5.69689C13.0436 5.78038 13.1841 5.86787 13.3161 5.95736C14.4293 6.70833 15.3008 7.76589 15.8252 9.00196C16.0021 9.42086 16.1371 9.85626 16.2282 10.3018C16.416 11.2225 16.416 12.1717 16.2282 13.0924C16.1372 13.538 16.0022 13.9734 15.8252 14.3922C15.3008 15.6288 14.4291 16.6869 13.3156 17.4383C13.1956 17.5193 13.0656 17.5998 12.9246 17.6838L13.6201 18.8812C13.7736 18.7917 13.9316 18.6927 14.0901 18.5867C15.4266 17.6852 16.4727 16.4154 17.1017 14.9312C17.3144 14.4288 17.4765 13.9064 17.5857 13.3719C17.8109 12.2667 17.8109 11.1275 17.5857 10.0223C17.4765 9.48779 17.3144 8.96545 17.1017 8.46303C16.4718 6.97942 15.4258 5.70983 14.0901 4.80751C13.9321 4.70252 13.7676 4.59904 13.5996 4.50255ZM12.4891 6.3948L11.8091 7.55215C11.9216 7.61514 12.0301 7.68213 12.1321 7.75212C12.3793 7.91952 12.61 8.11002 12.8211 8.32105C13.0326 8.53207 13.2233 8.76293 13.3906 9.01046C13.7307 9.51438 13.9686 10.0802 14.0906 10.6757C14.2172 11.2953 14.2172 11.934 14.0906 12.5535C13.9686 13.149 13.7307 13.7148 13.3906 14.2188C13.0552 14.7143 12.6282 15.1412 12.1326 15.4766C12.0141 15.5566 11.8921 15.6311 11.7696 15.6981L12.4466 16.8589C12.5966 16.7749 12.7466 16.6839 12.8851 16.5895C13.8501 15.9383 14.6056 15.0214 15.0601 13.9498C15.2137 13.5868 15.331 13.2095 15.4102 12.8235C15.6494 11.6585 15.5372 10.4487 15.0877 9.3476C14.6382 8.2465 13.8718 7.30369 12.8856 6.63877C12.7566 6.55228 12.6241 6.47129 12.4891 6.3948ZM7.71348 12.181H11.9306C11.9043 12.2832 11.8709 12.3835 11.8306 12.481C11.6044 13.0139 11.1798 13.4379 10.6465 13.6633L10.5995 13.6823L11.2771 14.8512C11.4498 14.7714 11.6159 14.6778 11.7736 14.5712C12.2575 14.2445 12.6539 13.8039 12.9279 13.2883C13.2019 12.7727 13.3452 12.1977 13.3452 11.6139C13.3452 11.03 13.2019 10.455 12.9279 9.9394C12.6539 9.42378 12.2575 8.98327 11.7736 8.6565C11.6274 8.55821 11.4744 8.47065 11.3156 8.39454L10.632 9.55938L10.6445 9.56488C10.9647 9.70036 11.2487 9.90879 11.4739 10.1735C11.6991 10.4383 11.8592 10.752 11.9416 11.0897H7.71348C7.60977 10.8926 7.45226 10.729 7.25926 10.6178C7.06625 10.5067 6.84566 10.4526 6.62313 10.4618C6.40059 10.471 6.18523 10.5432 6.00208 10.6699C5.81892 10.7966 5.67548 10.9727 5.58843 11.1777C5.46927 11.4573 5.46307 11.7723 5.57112 12.0564C5.67918 12.3406 5.89309 12.5718 6.16798 12.7017C6.44288 12.8315 6.75739 12.8499 7.04554 12.7529C7.33368 12.6559 7.57307 12.4512 7.71348 12.1815V12.181ZM6.67195 11.9711C6.6056 11.9711 6.54073 11.9514 6.48556 11.9145C6.43038 11.8777 6.38738 11.8253 6.36198 11.764C6.33659 11.7027 6.32995 11.6352 6.34289 11.5702C6.35584 11.5051 6.38779 11.4453 6.43471 11.3984C6.48164 11.3515 6.54142 11.3195 6.6065 11.3066C6.67158 11.2937 6.73904 11.3003 6.80035 11.3257C6.86165 11.3511 6.91405 11.3941 6.95092 11.4492C6.98778 11.5044 7.00746 11.5693 7.00746 11.6356C7.00733 11.7245 6.97194 11.8098 6.90905 11.8727C6.84616 11.9355 6.7609 11.9709 6.67195 11.9711V11.9711Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Google-Podcast' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Google-Podcast', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24V24ZM11.9966 16.2965C11.7497 16.2827 11.5073 16.3668 11.3221 16.5306C11.1369 16.6944 11.0239 16.9247 11.0076 17.1714V18.1263C11.0378 18.3671 11.1549 18.5887 11.337 18.7493C11.5191 18.91 11.7535 18.9986 11.9963 18.9986C12.2391 18.9986 12.4736 18.91 12.6557 18.7493C12.8377 18.5887 12.9549 18.3671 12.9851 18.1263V17.1709C12.9688 16.9243 12.8558 16.6942 12.6707 16.5305C12.4856 16.3667 12.2433 16.2827 11.9966 16.2965V16.2965ZM15.0411 10.9262C14.779 10.9265 14.5277 11.0307 14.3423 11.216C14.1569 11.4012 14.0525 11.6525 14.0521 11.9146V15.4201C14.0579 15.6785 14.1647 15.9243 14.3495 16.1049C14.5343 16.2856 14.7824 16.3867 15.0409 16.3867C15.2994 16.3867 15.5475 16.2856 15.7323 16.1049C15.9171 15.9243 16.0239 15.6785 16.0297 15.4201V11.9151C16.0294 11.6531 15.9253 11.402 15.7402 11.2167C15.5551 11.0313 15.3041 10.9269 15.0421 10.9262H15.0411ZM8.95251 13.3829C8.71585 13.3608 8.47992 13.432 8.29512 13.5815C8.11032 13.731 7.9913 13.9468 7.96348 14.1828V15.0552C7.99142 15.2911 8.11047 15.5068 8.29524 15.6563C8.48001 15.8057 8.71587 15.877 8.95251 15.8551C9.18908 15.877 9.42488 15.8057 9.60958 15.6562C9.79427 15.5068 9.91321 15.2911 9.94103 15.0552V14.1828C9.91321 13.9468 9.79427 13.7311 9.60958 13.5817C9.42488 13.4322 9.18908 13.3609 8.95251 13.3829V13.3829ZM11.9966 8.60201C11.7504 8.58746 11.5085 8.67061 11.3233 8.83339C11.1381 8.99618 11.0246 9.22545 11.0076 9.47139V14.5302C11.0387 14.7704 11.1562 14.9911 11.3381 15.151C11.5201 15.3109 11.7541 15.3991 11.9963 15.3991C12.2386 15.3991 12.4726 15.3109 12.6545 15.151C12.8365 14.9911 12.954 14.7704 12.9851 14.5302V9.4724C12.9683 9.22636 12.855 8.99691 12.6699 8.83393C12.4848 8.67095 12.2428 8.5876 11.9966 8.60201V8.60201ZM17.0192 11.4886V12.5675C17.0274 12.8242 17.1351 13.0676 17.3196 13.2463C17.5041 13.425 17.7509 13.5249 18.0077 13.5249C18.2646 13.5249 18.5114 13.425 18.6959 13.2463C18.8803 13.0676 18.9881 12.8242 18.9962 12.5675V11.4621C18.9962 11.3323 18.9707 11.2037 18.921 11.0838C18.8713 10.9639 18.7985 10.8549 18.7066 10.7631C18.6148 10.6713 18.5058 10.5984 18.3859 10.5488C18.2659 10.4991 18.1373 10.4735 18.0075 10.4735C17.8776 10.4735 17.749 10.4991 17.6291 10.5488C17.5091 10.5984 17.4001 10.6713 17.3083 10.7631C17.2165 10.8549 17.1436 10.9639 17.094 11.0838C17.0443 11.2037 17.0187 11.3323 17.0187 11.4621C17.0187 11.4711 17.0187 11.4806 17.0187 11.4901L17.0192 11.4886ZM5.98544 10.4738C5.7233 10.474 5.47197 10.5782 5.28656 10.7635C5.10116 10.9488 4.99681 11.2 4.99641 11.4621V12.5405C4.99641 12.8028 5.10062 13.0543 5.28609 13.2397C5.47157 13.4252 5.72313 13.5294 5.98544 13.5294C6.24774 13.5294 6.4993 13.4252 6.68478 13.2397C6.87026 13.0543 6.97446 12.8028 6.97446 12.5405V11.4621C6.97406 11.2 6.86972 10.9488 6.68431 10.7635C6.49891 10.5782 6.24757 10.474 5.98544 10.4738V10.4738ZM8.95251 8.14807C8.71587 8.12608 8.48001 8.19741 8.29524 8.34685C8.11047 8.49628 7.99142 8.712 7.96348 8.94796V11.8016C7.99822 12.0331 8.11978 12.2427 8.30347 12.3878C8.48716 12.5329 8.71922 12.6027 8.95251 12.583C9.18573 12.6029 9.41779 12.5332 9.60137 12.388C9.78496 12.2428 9.90625 12.0331 9.94053 11.8016V8.94796C9.91271 8.71213 9.79384 8.4965 9.60926 8.34707C9.42468 8.19763 9.189 8.12622 8.95251 8.14807V8.14807ZM15.0421 7.69813C14.7799 7.69839 14.5285 7.80266 14.3431 7.98805C14.1577 8.17345 14.0534 8.42482 14.0531 8.687V9.76686C14.0589 10.0252 14.1657 10.271 14.3505 10.4517C14.5353 10.6323 14.7834 10.7335 15.0419 10.7335C15.3004 10.7335 15.5485 10.6323 15.7333 10.4517C15.9181 10.271 16.0249 10.0252 16.0307 9.76686V8.6885C16.0304 8.4264 15.9262 8.17511 15.7409 7.98973C15.5556 7.80435 15.3043 7.70003 15.0421 7.69963V7.69813ZM11.9966 5.00248C11.7497 4.98864 11.5073 5.07277 11.3221 5.23659C11.1369 5.40041 11.0239 5.63068 11.0076 5.87737V6.83224C11.0378 7.07313 11.1549 7.29469 11.337 7.45532C11.5191 7.61595 11.7535 7.70459 11.9963 7.70459C12.2391 7.70459 12.4736 7.61595 12.6557 7.45532C12.8377 7.29469 12.9549 7.07313 12.9851 6.83224V5.87737C12.9689 5.63072 12.8559 5.40045 12.6708 5.23662C12.4857 5.07279 12.2434 4.98865 11.9966 5.00248Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'Apple-Podcast' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'Apple-Podcast', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24V24ZM11.7966 9.16644C11.3324 9.16604 10.8871 9.35001 10.5587 9.67787C10.396 9.84021 10.267 10.033 10.1788 10.2452C10.0907 10.4574 10.0452 10.6849 10.045 10.9147C10.0448 11.1445 10.0899 11.3721 10.1777 11.5844C10.2654 11.7968 10.3942 11.9898 10.5565 12.1524C10.8845 12.4808 11.3294 12.6656 11.7936 12.666V12.666C11.5019 12.6663 11.2137 12.7285 10.9479 12.8487C10.6822 12.9688 10.445 13.144 10.2522 13.3628C10.0593 13.5815 9.91514 13.8388 9.82926 14.1174C9.74338 14.3961 9.71774 14.6898 9.75403 14.9792L10.1145 17.8623C10.1503 18.1441 10.2876 18.4032 10.5006 18.5911C10.7137 18.779 10.9879 18.8829 11.2721 18.8832H12.3221C12.6061 18.8828 12.8803 18.779 13.0933 18.5911C13.3063 18.4032 13.4435 18.1441 13.4791 17.8623L13.8396 14.9792C13.8758 14.6897 13.8501 14.3958 13.7641 14.117C13.6781 13.8382 13.5338 13.5809 13.3408 13.3621C13.1478 13.1432 12.9105 12.9679 12.6447 12.8477C12.3788 12.7276 12.0904 12.6653 11.7986 12.665C12.2627 12.665 12.7078 12.4806 13.036 12.1525C13.3642 11.8243 13.5486 11.3793 13.5486 10.9152C13.5486 10.4511 13.3642 10.0061 13.036 9.67793C12.7078 9.34979 12.2627 9.16544 11.7986 9.16544L11.7966 9.16644ZM11.7966 5.6669C13.0105 5.66595 14.1923 6.05701 15.166 6.78187C16.1397 7.50673 16.8532 8.52662 17.2003 9.6897C17.5475 10.8528 17.5096 12.0968 17.0925 13.2367C16.6753 14.3765 15.9011 15.3512 14.8851 16.0155L14.7076 17.4508C16.1037 16.7903 17.2332 15.6742 17.9105 14.2863C18.5877 12.8985 18.7721 11.3214 18.4336 9.81474C18.095 8.30806 17.2536 6.96149 16.0477 5.99663C14.8418 5.03176 13.3433 4.50607 11.7988 4.50607C10.2543 4.50607 8.75587 5.03176 7.54998 5.99663C6.34409 6.96149 5.50263 8.30806 5.16406 9.81474C4.82549 11.3214 5.00999 12.8985 5.68719 14.2863C6.3644 15.6742 7.49396 16.7903 8.89001 17.4508L8.7105 16.0155C7.69455 15.3512 6.92036 14.3765 6.50319 13.2367C6.08602 12.0968 6.04818 10.8528 6.39531 9.6897C6.74243 8.52662 7.45595 7.50673 8.42964 6.78187C9.40334 6.05701 10.5851 5.66595 11.7991 5.6669H11.7966ZM11.7966 8.00209C12.3898 8.00133 12.9723 8.16048 13.4827 8.4628C13.9932 8.76512 14.4126 9.19942 14.697 9.71999C14.9814 10.2406 15.1202 10.8282 15.0987 11.4209C15.0773 12.0137 14.8964 12.5898 14.5751 13.0884C14.8127 13.4936 14.9595 13.9454 15.0056 14.4127C15.6169 13.7823 16.0289 12.9858 16.1901 12.1227C16.3514 11.2596 16.2549 10.3681 15.9125 9.55948C15.5701 8.7509 14.9971 8.06106 14.2651 7.57609C13.533 7.09111 12.6743 6.83247 11.7961 6.83247C10.9179 6.83247 10.0592 7.09111 9.32707 7.57609C8.595 8.06106 8.02201 8.7509 7.67965 9.55948C7.33729 10.3681 7.24072 11.2596 7.40199 12.1227C7.56327 12.9858 7.97525 13.7823 8.5865 14.4127C8.63261 13.9454 8.77948 13.4936 9.01701 13.0884C8.6957 12.5897 8.51483 12.0136 8.49342 11.4207C8.47202 10.8278 8.61087 10.2402 8.89537 9.71955C9.17987 9.19895 9.59949 8.76466 10.1101 8.46242C10.6206 8.16017 11.2032 8.00115 11.7966 8.00209V8.00209Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'RSS' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'RSS', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
						<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11.9966 24C9.22798 23.9984 6.54504 23.04 4.40229 21.2871C2.25953 19.5342 0.788706 17.0945 0.238998 14.3815C-0.310711 11.6684 0.0944951 8.84877 1.38597 6.40023C2.67744 3.95169 4.77577 2.02481 7.32547 0.94602C10.258 -0.292643 13.5626 -0.315796 16.5123 0.881653C19.4619 2.0791 21.815 4.39907 23.0538 7.33118C24.2927 10.2633 24.3158 13.5674 23.1182 16.5165C21.9206 19.4657 19.6003 21.8184 16.6677 23.0571C15.19 23.6824 13.6012 24.0031 11.9966 24V24ZM6.49645 5.50242V7.78762C9.07291 7.78775 11.5438 8.81115 13.3657 10.6327C15.1875 12.4543 16.211 14.9248 16.2112 17.5008H18.4967C18.4993 15.898 18.1781 14.3111 17.5522 12.8355C16.6346 10.6617 15.0965 8.8067 13.13 7.50241C11.1636 6.19812 8.85622 5.50246 6.49645 5.50242V5.50242ZM6.49645 9.50189V11.7876C8.01145 11.7893 9.46391 12.3918 10.5352 13.4628C11.6065 14.5339 12.2092 15.9861 12.2111 17.5008H14.4966C14.4943 15.3801 13.6506 13.3469 12.1508 11.8474C10.651 10.3478 8.6175 9.50427 6.49645 9.50189V9.50189ZM8.21149 14.0723C7.87239 14.0722 7.54087 14.1726 7.25886 14.3609C6.97685 14.5492 6.75701 14.8169 6.62715 15.1301C6.49729 15.4433 6.46324 15.788 6.5293 16.1205C6.59536 16.4531 6.75856 16.7586 6.99827 16.9984C7.23799 17.2382 7.54344 17.4016 7.87601 17.4678C8.20858 17.534 8.55332 17.5002 8.86665 17.3705C9.17998 17.2409 9.44782 17.0212 9.6363 16.7394C9.82478 16.4575 9.92543 16.1261 9.92553 15.7871C9.92513 15.3325 9.74447 14.8967 9.42315 14.5751C9.10184 14.2536 8.6661 14.0726 8.21149 14.0718V14.0723Z" fill="white"/>
						</svg>
					</a>
				</div>
				<?php
			} else if ( 'E-mail' === $active_site ) {
				?>
				<div class="social-links">
					<a href="<?php echo esc_url( get_theme_mod( $active_site ) ); ?>" class="<?php echo esc_attr( mb_strtolower( $class ) ); ?>" target="_blank" title="<?php printf( esc_attr__( 'E-mail', 'minnak' ), esc_attr( $active_site ) ); ?>" data-toggle="tooltip" data-placement="top">
					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
						<path fill-rule="evenodd" clip-rule="evenodd" d="M4.40235 21.2871C6.54514 23.04 9.22812 23.9984 11.9968 24C13.6012 24.0031 15.1898 23.6824 16.6674 23.0571C19.6 21.8185 21.9204 19.4658 23.1181 16.5167C24.3158 13.5676 24.2927 10.2635 23.0539 7.33136C21.8151 4.39924 19.4621 2.07924 16.5124 0.88174C13.5628 -0.315762 10.2582 -0.292671 7.32558 0.94593C4.77584 2.02472 2.67748 3.95162 1.38599 6.40017C0.0944972 8.84872 -0.310714 11.6684 0.239002 14.3814C0.788719 17.0945 2.25956 19.5341 4.40235 21.2871ZM11.5395 11.7611C11.8282 11.9109 12.1718 11.9109 12.4605 11.7611L18.5 8.62761V7.83334C18.5 7.59896 18.4196 7.40148 18.2588 7.24089C18.098 7.0803 17.9076 7 17.6875 7H6.3125C6.09245 7 5.90202 7.0803 5.74121 7.24089C5.5804 7.40148 5.5 7.59896 5.5 7.83334V8.62761L11.5395 11.7611ZM12 13C11.7333 13 11.4706 12.9345 11.2351 12.8092L5.5 9.75782V16.1667C5.5 16.3924 5.5804 16.5877 5.74121 16.7526C5.90202 16.9175 6.09245 17 6.3125 17H17.6875C17.9076 17 18.098 16.9175 18.2588 16.7526C18.4196 16.5877 18.5 16.3924 18.5 16.1667V9.75782L12.7649 12.8092C12.5294 12.9345 12.2667 13 12 13Z" fill="white"/>
					</svg>
					</a>
				</div>
				<?php
			}
		}
		echo '</div>';
	}
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function minnak_customize_preview_js() {
	wp_enqueue_script( 'minnak-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'minnak_customize_preview_js' );
